@@ -22,6 +22,9 @@
 
 #include <ccode/valaccodedeclarator.h>
 
+
+
+
 enum  {
 	VALA_CCODE_DECLARATOR_DUMMY_PROPERTY
 };
@@ -29,6 +32,7 @@ static void vala_ccode_declarator_real_write_initialization (ValaCCodeDeclarator
 static gpointer vala_ccode_declarator_parent_class = NULL;
 
 
+
 /**
  * Writes initialization statements for this declarator with the
  * specified C code writer if necessary.
@@ -37,7 +41,7 @@ static gpointer vala_ccode_declarator_parent_class = NULL;
  */
 static void vala_ccode_declarator_real_write_initialization (ValaCCodeDeclarator* self, ValaCCodeWriter* writer) {
 	g_return_if_fail (VALA_IS_CCODE_DECLARATOR (self));
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 }
 
 
@@ -46,6 +50,16 @@ void vala_ccode_declarator_write_initialization (ValaCCodeDeclarator* self, Vala
 }
 
 
+/**
+ * Represents a variable or function pointer declarator in the C code.
+ */
+ValaCCodeDeclarator* vala_ccode_declarator_new (void) {
+	ValaCCodeDeclarator * self;
+	self = g_object_newv (VALA_TYPE_CCODE_DECLARATOR, 0, NULL);
+	return self;
+}
+
+
 static void vala_ccode_declarator_class_init (ValaCCodeDeclaratorClass * klass) {
 	vala_ccode_declarator_parent_class = g_type_class_peek_parent (klass);
 	VALA_CCODE_DECLARATOR_CLASS (klass)->write_initialization = vala_ccode_declarator_real_write_initialization;
