@@ -38,6 +38,7 @@ struct _ValaCCodeForStatementPrivate {
 	GeeList* initializer;
 	GeeList* iterator;
 };
+
 #define VALA_CCODE_FOR_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FOR_STATEMENT, ValaCCodeForStatementPrivate))
 enum  {
 	VALA_CCODE_FOR_STATEMENT_DUMMY_PROPERTY,
@@ -52,11 +53,11 @@ static void vala_ccode_for_statement_dispose (GObject * obj);
 
 ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condition, ValaCCodeStatement* body) {
 	ValaCCodeForStatement * self;
-	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (condition), NULL);
+	g_return_val_if_fail (condition == NULL || VALA_IS_CCODE_EXPRESSION (condition), NULL);
 	g_return_val_if_fail (body == NULL || VALA_IS_CCODE_STATEMENT (body), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_FOR_STATEMENT, 0, NULL);
-	vala_ccode_for_statement_set_body (self, body);
 	vala_ccode_for_statement_set_condition (self, condition);
+	vala_ccode_for_statement_set_body (self, body);
 	return self;
 }
 
