@@ -36,7 +36,7 @@ static gpointer vala_ccode_newline_parent_class = NULL;
 static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeNewline * self;
 	self = VALA_CCODE_NEWLINE (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_newline (writer);
 }
 
