@@ -24,9 +24,13 @@
 #include <ccode/valaccodelinedirective.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeOnceSectionPrivate {
 	char* _define;
 };
+
 #define VALA_CCODE_ONCE_SECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ONCE_SECTION, ValaCCodeOnceSectionPrivate))
 enum  {
 	VALA_CCODE_ONCE_SECTION_DUMMY_PROPERTY,
@@ -38,10 +42,12 @@ static gpointer vala_ccode_once_section_parent_class = NULL;
 static void vala_ccode_once_section_dispose (GObject * obj);
 
 
+
 ValaCCodeOnceSection* vala_ccode_once_section_new (const char* def) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeOnceSection * self;
+	g_return_val_if_fail (def != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "define";
@@ -61,13 +67,13 @@ ValaCCodeOnceSection* vala_ccode_once_section_new (const char* def) {
 static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeOnceSection * self;
 	self = VALA_CCODE_ONCE_SECTION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#ifndef ");
-	vala_ccode_writer_write_string (writer, vala_ccode_once_section_get_define (self));
+	vala_ccode_writer_write_string (writer, self->priv->_define);
 	vala_ccode_writer_write_newline (writer);
 	vala_ccode_writer_write_string (writer, "#define ");
-	vala_ccode_writer_write_string (writer, vala_ccode_once_section_get_define (self));
+	vala_ccode_writer_write_string (writer, self->priv->_define);
 	vala_ccode_writer_write_newline (writer);
 	{
 		GeeCollection* node_collection;
@@ -94,7 +100,7 @@ static void vala_ccode_once_section_real_write (ValaCCodeNode* base, ValaCCodeWr
 static void vala_ccode_once_section_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeOnceSection * self;
 	self = VALA_CCODE_ONCE_SECTION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 }
 
 
