@@ -45,15 +45,19 @@ typedef struct _ValaCCodeStatementPrivate ValaCCodeStatementPrivate;
  * Represents a statement in the C code.
  */
 struct _ValaCCodeStatement {
-	ValaCCodeNode parent;
+	ValaCCodeNode parent_instance;
 	ValaCCodeStatementPrivate * priv;
 };
+
 struct _ValaCCodeStatementClass {
-	ValaCCodeNodeClass parent;
+	ValaCCodeNodeClass parent_class;
 };
 
+
+ValaCCodeStatement* vala_ccode_statement_new (void);
 GType vala_ccode_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
