@@ -49,13 +49,15 @@ typedef struct _ValaCCodeTypeDefinitionPrivate ValaCCodeTypeDefinitionPrivate;
  * Represents a typedef in the C code.
  */
 struct _ValaCCodeTypeDefinition {
-	ValaCCodeNode parent;
+	ValaCCodeNode parent_instance;
 	ValaCCodeTypeDefinitionPrivate * priv;
 };
+
 struct _ValaCCodeTypeDefinitionClass {
-	ValaCCodeNodeClass parent;
+	ValaCCodeNodeClass parent_class;
 };
 
+
 ValaCCodeTypeDefinition* vala_ccode_type_definition_new (const char* type, ValaCCodeDeclarator* decl);
 char* vala_ccode_type_definition_get_type_name (ValaCCodeTypeDefinition* self);
 void vala_ccode_type_definition_set_type_name (ValaCCodeTypeDefinition* self, const char* value);
@@ -63,6 +65,7 @@ ValaCCodeDeclarator* vala_ccode_type_definition_get_declarator (ValaCCodeTypeDef
 void vala_ccode_type_definition_set_declarator (ValaCCodeTypeDefinition* self, ValaCCodeDeclarator* value);
 GType vala_ccode_type_definition_get_type (void);
 
+
 G_END_DECLS
 
 #endif
