@@ -38,17 +38,20 @@ struct _GeeReadOnlyListIterator {
 	GObject parent_instance;
 	GeeReadOnlyListIteratorPrivate * priv;
 };
+
 struct _GeeReadOnlyListIteratorClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _GeeReadOnlyListPrivate {
 	GeeList* _list;
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_READ_ONLY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_LIST, GeeReadOnlyListPrivate))
 enum  {
 	GEE_READ_ONLY_LIST_DUMMY_PROPERTY,
@@ -74,6 +77,7 @@ struct _GeeReadOnlyListIteratorPrivate {
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_READ_ONLY_LIST_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_LIST_TYPE_ITERATOR, GeeReadOnlyListIteratorPrivate))
 enum  {
 	GEE_READ_ONLY_LIST_ITERATOR_DUMMY_PROPERTY,
@@ -96,13 +100,31 @@ static void gee_read_only_list_dispose (GObject * obj);
 
 
 GeeReadOnlyList* gee_read_only_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeList* list) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeReadOnlyList * self;
 	g_return_val_if_fail (list == NULL || GEE_IS_LIST (list), NULL);
-	self = g_object_newv (GEE_TYPE_READ_ONLY_LIST, 0, NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_READ_ONLY_LIST, __params_it - __params, __params);
 	gee_read_only_list_set_list (self, list);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -227,11 +249,29 @@ static gpointer gee_read_only_list_iterator_real_get (GeeIterator* base) {
 
 
 static GeeReadOnlyListIterator* gee_read_only_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeReadOnlyListIterator * self;
-	self = g_object_newv (GEE_READ_ONLY_LIST_TYPE_ITERATOR, 0, NULL);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_READ_ONLY_LIST_TYPE_ITERATOR, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -272,9 +312,9 @@ static void gee_read_only_list_iterator_class_init (GeeReadOnlyListIteratorClass
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyListIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_list_iterator_set_property;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -345,9 +385,9 @@ static void gee_read_only_list_class_init (GeeReadOnlyListClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_list_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_list_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_read_only_list_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_LIST_LIST, g_param_spec_object ("list", "list", "list", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
