@@ -25,6 +25,7 @@
 #include <string.h>
 #include <glib/gstdio.h>
 #include <config.h>
+#include <string.h>
 
 
 #define VALA_TYPE_PROJECT_TYPE (vala_project_type_get_type ())
@@ -58,11 +59,13 @@ struct _ValaProjectGenerator {
 	GtkDialog parent_instance;
 	ValaProjectGeneratorPrivate * priv;
 };
+
 struct _ValaProjectGeneratorClass {
 	GtkDialogClass parent_class;
 };
 
 
+
 GType vala_project_type_get_type (void);
 GType vala_project_license_get_type (void);
 struct _ValaProjectGeneratorPrivate {
@@ -81,6 +84,7 @@ struct _ValaProjectGeneratorPrivate {
 	ValaProjectType project_type;
 	ValaProjectLicense project_license;
 };
+
 #define VALA_PROJECT_GENERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROJECT_GENERATOR, ValaProjectGeneratorPrivate))
 enum  {
 	VALA_PROJECT_GENERATOR_DUMMY_PROPERTY
@@ -653,74 +657,75 @@ static void vala_project_generator_write_makefile_am (ValaProjectGenerator* self
 static char* vala_project_generator_generate_source_file_header (ValaProjectGenerator* self, const char* filename) {
 	GString* s;
 	GTimeVal tv = {0};
-	GDate* d;
+	GDate _tmp0 = {0};
+	GDate d;
 	char* license_name;
 	char* license_version;
 	char* program_type;
-	ValaProjectLicense _tmp12;
-	const char* _tmp13;
-	char* _tmp14;
+	ValaProjectLicense _tmp13;
+	const char* _tmp14;
+	char* _tmp15;
 	g_return_val_if_fail (VALA_IS_PROJECT_GENERATOR (self), NULL);
 	g_return_val_if_fail (filename != NULL, NULL);
 	s = g_string_new ("");
 	g_get_current_time (&tv);
-	d = g_date_new ();
-	g_date_set_time_val (d, &tv);
+	d = (memset (&_tmp0, 0, sizeof (GDate)), _tmp0);
+	g_date_set_time_val (&d, &tv);
 	g_string_append_printf (s, "/* %s\n", filename);
 	g_string_append (s, " *\n");
-	g_string_append_printf (s, " * Copyright (C) %d  %s\n", g_date_get_year (d), self->priv->real_name);
+	g_string_append_printf (s, " * Copyright (C) %d  %s\n", g_date_get_year (&d), self->priv->real_name);
 	g_string_append (s, " *\n");
 	license_name = g_strdup ("");
 	license_version = NULL;
 	program_type = NULL;
-	_tmp12 = self->priv->project_license;
-	if (_tmp12 == VALA_PROJECT_LICENSE_GPL2)
+	_tmp13 = self->priv->project_license;
+	if (_tmp13 == VALA_PROJECT_LICENSE_GPL2)
 	do {
-		char* _tmp0;
 		char* _tmp1;
 		char* _tmp2;
-		_tmp0 = NULL;
-		license_name = (_tmp0 = g_strdup ("GNU General Public License"), (license_name = (g_free (license_name), NULL)), _tmp0);
-		_tmp1 = NULL;
-		license_version = (_tmp1 = g_strdup ("2"), (license_version = (g_free (license_version), NULL)), _tmp1);
-		_tmp2 = NULL;
-		program_type = (_tmp2 = g_strdup ("program"), (program_type = (g_free (program_type), NULL)), _tmp2);
-		break;
-	} while (0); else if (_tmp12 == VALA_PROJECT_LICENSE_GPL3)
-	do {
 		char* _tmp3;
+		_tmp1 = NULL;
+		license_name = (_tmp1 = g_strdup ("GNU General Public License"), (license_name = (g_free (license_name), NULL)), _tmp1);
+		_tmp2 = NULL;
+		license_version = (_tmp2 = g_strdup ("2"), (license_version = (g_free (license_version), NULL)), _tmp2);
+		_tmp3 = NULL;
+		program_type = (_tmp3 = g_strdup ("program"), (program_type = (g_free (program_type), NULL)), _tmp3);
+		break;
+	} while (0); else if (_tmp13 == VALA_PROJECT_LICENSE_GPL3)
+	do {
 		char* _tmp4;
 		char* _tmp5;
-		_tmp3 = NULL;
-		license_name = (_tmp3 = g_strdup ("GNU General Public License"), (license_name = (g_free (license_name), NULL)), _tmp3);
-		_tmp4 = NULL;
-		license_version = (_tmp4 = g_strdup ("3"), (license_version = (g_free (license_version), NULL)), _tmp4);
-		_tmp5 = NULL;
-		program_type = (_tmp5 = g_strdup ("program"), (program_type = (g_free (program_type), NULL)), _tmp5);
-		break;
-	} while (0); else if (_tmp12 == VALA_PROJECT_LICENSE_LGPL2)
-	do {
 		char* _tmp6;
+		_tmp4 = NULL;
+		license_name = (_tmp4 = g_strdup ("GNU General Public License"), (license_name = (g_free (license_name), NULL)), _tmp4);
+		_tmp5 = NULL;
+		license_version = (_tmp5 = g_strdup ("3"), (license_version = (g_free (license_version), NULL)), _tmp5);
+		_tmp6 = NULL;
+		program_type = (_tmp6 = g_strdup ("program"), (program_type = (g_free (program_type), NULL)), _tmp6);
+		break;
+	} while (0); else if (_tmp13 == VALA_PROJECT_LICENSE_LGPL2)
+	do {
 		char* _tmp7;
 		char* _tmp8;
-		_tmp6 = NULL;
-		license_name = (_tmp6 = g_strdup ("GNU Lesser General Public License"), (license_name = (g_free (license_name), NULL)), _tmp6);
-		_tmp7 = NULL;
-		license_version = (_tmp7 = g_strdup ("2.1"), (license_version = (g_free (license_version), NULL)), _tmp7);
-		_tmp8 = NULL;
-		program_type = (_tmp8 = g_strdup ("library"), (program_type = (g_free (program_type), NULL)), _tmp8);
-		break;
-	} while (0); else if (_tmp12 == VALA_PROJECT_LICENSE_LGPL3)
-	do {
 		char* _tmp9;
+		_tmp7 = NULL;
+		license_name = (_tmp7 = g_strdup ("GNU Lesser General Public License"), (license_name = (g_free (license_name), NULL)), _tmp7);
+		_tmp8 = NULL;
+		license_version = (_tmp8 = g_strdup ("2.1"), (license_version = (g_free (license_version), NULL)), _tmp8);
+		_tmp9 = NULL;
+		program_type = (_tmp9 = g_strdup ("library"), (program_type = (g_free (program_type), NULL)), _tmp9);
+		break;
+	} while (0); else if (_tmp13 == VALA_PROJECT_LICENSE_LGPL3)
+	do {
 		char* _tmp10;
 		char* _tmp11;
-		_tmp9 = NULL;
-		license_name = (_tmp9 = g_strdup ("GNU Lesser General Public License"), (license_name = (g_free (license_name), NULL)), _tmp9);
+		char* _tmp12;
 		_tmp10 = NULL;
-		license_version = (_tmp10 = g_strdup ("3"), (license_version = (g_free (license_version), NULL)), _tmp10);
+		license_name = (_tmp10 = g_strdup ("GNU Lesser General Public License"), (license_name = (g_free (license_name), NULL)), _tmp10);
 		_tmp11 = NULL;
-		program_type = (_tmp11 = g_strdup ("library"), (program_type = (g_free (program_type), NULL)), _tmp11);
+		license_version = (_tmp11 = g_strdup ("3"), (license_version = (g_free (license_version), NULL)), _tmp11);
+		_tmp12 = NULL;
+		program_type = (_tmp12 = g_strdup ("library"), (program_type = (g_free (program_type), NULL)), _tmp12);
 		break;
 	} while (0);
 	g_string_append_printf (s, " * This %s is free software: you can redistribute it and/or modify\n", program_type);
@@ -739,9 +744,9 @@ static char* vala_project_generator_generate_source_file_header (ValaProjectGene
 	g_string_append (s, " * Author:\n");
 	g_string_append_printf (s, " * \t%s <%s>\n", self->priv->real_name, self->priv->email_address);
 	g_string_append (s, " */\n\n");
-	_tmp13 = NULL;
 	_tmp14 = NULL;
-	return (_tmp14 = (_tmp13 = s->str, (_tmp13 == NULL ? NULL : g_strdup (_tmp13))), (s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL))), (d == NULL ? NULL : (d = (g_date_free (d), NULL))), (license_name = (g_free (license_name), NULL)), (license_version = (g_free (license_version), NULL)), (program_type = (g_free (program_type), NULL)), _tmp14);
+	_tmp15 = NULL;
+	return (_tmp15 = (_tmp14 = s->str, (_tmp14 == NULL ? NULL : g_strdup (_tmp14))), (s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL))), (license_name = (g_free (license_name), NULL)), (license_version = (g_free (license_version), NULL)), (program_type = (g_free (program_type), NULL)), _tmp15);
 }
 
 
