@@ -102,7 +102,7 @@ void vala_ccode_dynamic_method_binding_generate_wrapper (ValaCCodeDynamicMethodB
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	_tmp3 = NULL;
-	func = (_tmp3 = vala_ccode_function_new ((_tmp1 = vala_method_get_cname (vala_ccode_method_binding_get_method (VALA_CCODE_METHOD_BINDING (self)))), (_tmp2 = vala_data_type_get_cname (vala_method_get_return_type (vala_ccode_method_binding_get_method (VALA_CCODE_METHOD_BINDING (self))), FALSE, FALSE))), (_tmp2 = (g_free (_tmp2), NULL)), (_tmp1 = (g_free (_tmp1), NULL)), _tmp3);
+	func = (_tmp3 = vala_ccode_function_new ((_tmp1 = vala_method_get_cname (vala_ccode_method_binding_get_method (VALA_CCODE_METHOD_BINDING (self)))), (_tmp2 = vala_data_type_get_cname (vala_method_get_return_type (vala_ccode_method_binding_get_method (VALA_CCODE_METHOD_BINDING (self)))))), (_tmp2 = (g_free (_tmp2), NULL)), (_tmp1 = (g_free (_tmp1), NULL)), _tmp3);
 	cparam_map = gee_hash_map_new (G_TYPE_INT, NULL, NULL, VALA_TYPE_CCODE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_hash, g_direct_equal, g_direct_equal);
 	instance_param = vala_ccode_formal_parameter_new ("obj", "gpointer");
 	gee_map_set (GEE_MAP (cparam_map), GINT_TO_POINTER (vala_ccode_generator_get_param_pos (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_method_get_cinstance_parameter_position (vala_ccode_method_binding_get_method (VALA_CCODE_METHOD_BINDING (self))), FALSE)), instance_param);
@@ -391,51 +391,53 @@ static void vala_ccode_dynamic_method_binding_generate_dbus_method_wrapper (Vala
 						ValaCCodeDeclaration* _tmp38;
 						ValaCCodeDeclaration* cdecl_;
 						ValaCCodeVariableDeclarator* _tmp39;
-						ValaCCodeUnaryExpression* _tmp47;
-						ValaCCodeIdentifier* _tmp46;
-						ValaCCodeIdentifier* _tmp48;
+						ValaCCodeUnaryExpression* _tmp44;
+						ValaCCodeIdentifier* _tmp43;
+						ValaCCodeIdentifier* _tmp45;
 						_tmp37 = NULL;
 						_tmp38 = NULL;
-						cdecl_ = (_tmp38 = vala_ccode_declaration_new ((_tmp37 = vala_data_type_get_cname (vala_formal_parameter_get_type_reference (param), FALSE, FALSE))), (_tmp37 = (g_free (_tmp37), NULL)), _tmp38);
+						cdecl_ = (_tmp38 = vala_ccode_declaration_new ((_tmp37 = vala_data_type_get_cname (vala_formal_parameter_get_type_reference (param)))), (_tmp37 = (g_free (_tmp37), NULL)), _tmp38);
 						_tmp39 = NULL;
 						vala_ccode_declaration_add_declarator (cdecl_, VALA_CCODE_DECLARATOR ((_tmp39 = vala_ccode_variable_declarator_new (vala_symbol_get_name (VALA_SYMBOL (param))))));
 						(_tmp39 == NULL ? NULL : (_tmp39 = (g_object_unref (_tmp39), NULL)));
 						vala_ccode_block_add_statement (vala_ccode_function_get_block (cb_fun), VALA_CCODE_NODE (cdecl_));
 						if (VALA_IS_ARRAY_TYPE (vala_formal_parameter_get_type_reference (param)) && vala_data_type_get_data_type (vala_array_type_get_element_type ((VALA_ARRAY_TYPE (vala_formal_parameter_get_type_reference (param))))) == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
 							ValaCCodeIdentifier* _tmp40;
-							ValaCCodeIdentifier* _tmp41;
-							ValaCCodeFunctionCall* _tmp42;
-							ValaCCodeFunctionCall* cstrvlen;
-							ValaCCodeIdentifier* _tmp43;
 							/* special case string array*/
 							_tmp40 = NULL;
 							vala_ccode_function_call_add_argument (cend_call, VALA_CCODE_EXPRESSION ((_tmp40 = vala_ccode_identifier_new ("G_TYPE_STRV"))));
 							(_tmp40 == NULL ? NULL : (_tmp40 = (g_object_unref (_tmp40), NULL)));
-							_tmp41 = NULL;
+						} else {
+							ValaCCodeIdentifier* _tmp42;
+							char* _tmp41;
 							_tmp42 = NULL;
-							cstrvlen = (_tmp42 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp41 = vala_ccode_identifier_new ("g_strv_length")))), (_tmp41 == NULL ? NULL : (_tmp41 = (g_object_unref (_tmp41), NULL))), _tmp42);
-							_tmp43 = NULL;
-							vala_ccode_function_call_add_argument (cstrvlen, VALA_CCODE_EXPRESSION ((_tmp43 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (param))))));
-							(_tmp43 == NULL ? NULL : (_tmp43 = (g_object_unref (_tmp43), NULL)));
+							_tmp41 = NULL;
+							vala_ccode_function_call_add_argument (cend_call, VALA_CCODE_EXPRESSION ((_tmp42 = vala_ccode_identifier_new ((_tmp41 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_formal_parameter_get_type_reference (param))))))));
+							(_tmp42 == NULL ? NULL : (_tmp42 = (g_object_unref (_tmp42), NULL)));
+							_tmp41 = (g_free (_tmp41), NULL);
+						}
+						_tmp44 = NULL;
+						_tmp43 = NULL;
+						vala_ccode_function_call_add_argument (cend_call, VALA_CCODE_EXPRESSION ((_tmp44 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION ((_tmp43 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (param)))))))));
+						(_tmp44 == NULL ? NULL : (_tmp44 = (g_object_unref (_tmp44), NULL)));
+						(_tmp43 == NULL ? NULL : (_tmp43 = (g_object_unref (_tmp43), NULL)));
+						_tmp45 = NULL;
+						vala_ccode_function_call_add_argument (creply_call, VALA_CCODE_EXPRESSION ((_tmp45 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (param))))));
+						(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
+						if (VALA_IS_ARRAY_TYPE (vala_formal_parameter_get_type_reference (param)) && vala_data_type_get_data_type (vala_array_type_get_element_type ((VALA_ARRAY_TYPE (vala_formal_parameter_get_type_reference (param))))) == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
+							ValaCCodeIdentifier* _tmp46;
+							ValaCCodeFunctionCall* _tmp47;
+							ValaCCodeFunctionCall* cstrvlen;
+							ValaCCodeIdentifier* _tmp48;
+							_tmp46 = NULL;
+							_tmp47 = NULL;
+							cstrvlen = (_tmp47 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp46 = vala_ccode_identifier_new ("g_strv_length")))), (_tmp46 == NULL ? NULL : (_tmp46 = (g_object_unref (_tmp46), NULL))), _tmp47);
+							_tmp48 = NULL;
+							vala_ccode_function_call_add_argument (cstrvlen, VALA_CCODE_EXPRESSION ((_tmp48 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (param))))));
+							(_tmp48 == NULL ? NULL : (_tmp48 = (g_object_unref (_tmp48), NULL)));
 							vala_ccode_function_call_add_argument (creply_call, VALA_CCODE_EXPRESSION (cstrvlen));
 							(cstrvlen == NULL ? NULL : (cstrvlen = (g_object_unref (cstrvlen), NULL)));
-						} else {
-							ValaCCodeIdentifier* _tmp45;
-							char* _tmp44;
-							_tmp45 = NULL;
-							_tmp44 = NULL;
-							vala_ccode_function_call_add_argument (cend_call, VALA_CCODE_EXPRESSION ((_tmp45 = vala_ccode_identifier_new ((_tmp44 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_formal_parameter_get_type_reference (param))))))));
-							(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
-							_tmp44 = (g_free (_tmp44), NULL);
 						}
-						_tmp47 = NULL;
-						_tmp46 = NULL;
-						vala_ccode_function_call_add_argument (cend_call, VALA_CCODE_EXPRESSION ((_tmp47 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION ((_tmp46 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (param)))))))));
-						(_tmp47 == NULL ? NULL : (_tmp47 = (g_object_unref (_tmp47), NULL)));
-						(_tmp46 == NULL ? NULL : (_tmp46 = (g_object_unref (_tmp46), NULL)));
-						_tmp48 = NULL;
-						vala_ccode_function_call_add_argument (creply_call, VALA_CCODE_EXPRESSION ((_tmp48 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (param))))));
-						(_tmp48 == NULL ? NULL : (_tmp48 = (g_object_unref (_tmp48), NULL)));
 						(cdecl_ == NULL ? NULL : (cdecl_ = (g_object_unref (cdecl_), NULL)));
 					}
 					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
@@ -553,7 +555,7 @@ static void vala_ccode_dynamic_method_binding_generate_dbus_method_wrapper (Vala
 			garray_type_reference = vala_ccode_generator_get_data_type_for_symbol (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->garray_type);
 			_tmp67 = NULL;
 			_tmp68 = NULL;
-			cdecl_ = (_tmp68 = vala_ccode_declaration_new ((_tmp67 = vala_data_type_get_cname (garray_type_reference, FALSE, FALSE))), (_tmp67 = (g_free (_tmp67), NULL)), _tmp68);
+			cdecl_ = (_tmp68 = vala_ccode_declaration_new ((_tmp67 = vala_data_type_get_cname (garray_type_reference))), (_tmp67 = (g_free (_tmp67), NULL)), _tmp68);
 			_tmp69 = NULL;
 			vala_ccode_declaration_add_declarator (cdecl_, VALA_CCODE_DECLARATOR ((_tmp69 = vala_ccode_variable_declarator_new ("result"))));
 			(_tmp69 == NULL ? NULL : (_tmp69 = (g_object_unref (_tmp69), NULL)));
@@ -622,7 +624,7 @@ static void vala_ccode_dynamic_method_binding_generate_dbus_method_wrapper (Vala
 			}
 			_tmp83 = NULL;
 			_tmp84 = NULL;
-			cdecl_ = (_tmp84 = vala_ccode_declaration_new ((_tmp83 = vala_data_type_get_cname (vala_method_get_return_type (vala_ccode_method_binding_get_method (VALA_CCODE_METHOD_BINDING (self))), FALSE, FALSE))), (_tmp83 = (g_free (_tmp83), NULL)), _tmp84);
+			cdecl_ = (_tmp84 = vala_ccode_declaration_new ((_tmp83 = vala_data_type_get_cname (vala_method_get_return_type (vala_ccode_method_binding_get_method (VALA_CCODE_METHOD_BINDING (self)))))), (_tmp83 = (g_free (_tmp83), NULL)), _tmp84);
 			_tmp85 = NULL;
 			vala_ccode_declaration_add_declarator (cdecl_, VALA_CCODE_DECLARATOR ((_tmp85 = vala_ccode_variable_declarator_new ("result"))));
 			(_tmp85 == NULL ? NULL : (_tmp85 = (g_object_unref (_tmp85), NULL)));
