@@ -53,11 +53,13 @@ struct _ValaCCodeDynamicSignalBindingPrivate {
 	char* connect_wrapper_name;
 	char* disconnect_wrapper_name;
 };
+
 #define VALA_CCODE_DYNAMIC_SIGNAL_BINDING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_DYNAMIC_SIGNAL_BINDING, ValaCCodeDynamicSignalBindingPrivate))
 enum  {
 	VALA_CCODE_DYNAMIC_SIGNAL_BINDING_DUMMY_PROPERTY,
 	VALA_CCODE_DYNAMIC_SIGNAL_BINDING_NODE
 };
+static gint vala_ccode_dynamic_signal_binding_signal_wrapper_id;
 static void vala_ccode_dynamic_signal_binding_generate_dbus_connect_wrapper (ValaCCodeDynamicSignalBinding* self, ValaCCodeBlock* block);
 static void vala_ccode_dynamic_signal_binding_generate_dbus_disconnect_wrapper (ValaCCodeDynamicSignalBinding* self, ValaCCodeBlock* block);
 static gpointer vala_ccode_dynamic_signal_binding_parent_class = NULL;
@@ -94,7 +96,7 @@ char* vala_ccode_dynamic_signal_binding_get_connect_wrapper_name (ValaCCodeDynam
 		ValaCCodeBlock* block;
 		ValaCCodeFunction* _tmp8;
 		_tmp1 = NULL;
-		self->priv->connect_wrapper_name = (_tmp1 = g_strdup_printf ("_dynamic_%s_connect", vala_symbol_get_name (VALA_SYMBOL (self->priv->_node))), (self->priv->connect_wrapper_name = (g_free (self->priv->connect_wrapper_name), NULL)), _tmp1);
+		self->priv->connect_wrapper_name = (_tmp1 = g_strdup_printf ("_dynamic_%s%d_connect", vala_symbol_get_name (VALA_SYMBOL (self->priv->_node)), vala_ccode_dynamic_signal_binding_signal_wrapper_id++), (self->priv->connect_wrapper_name = (g_free (self->priv->connect_wrapper_name), NULL)), _tmp1);
 		func = vala_ccode_function_new (self->priv->connect_wrapper_name, "void");
 		_tmp2 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp2 = vala_ccode_formal_parameter_new ("obj", "gpointer")));
@@ -153,7 +155,7 @@ char* vala_ccode_dynamic_signal_binding_get_disconnect_wrapper_name (ValaCCodeDy
 		ValaCCodeBlock* block;
 		ValaCCodeFunction* _tmp8;
 		_tmp1 = NULL;
-		self->priv->disconnect_wrapper_name = (_tmp1 = g_strdup_printf ("_dynamic_%s_disconnect", vala_symbol_get_name (VALA_SYMBOL (self->priv->_node))), (self->priv->disconnect_wrapper_name = (g_free (self->priv->disconnect_wrapper_name), NULL)), _tmp1);
+		self->priv->disconnect_wrapper_name = (_tmp1 = g_strdup_printf ("_dynamic_%s%d_disconnect", vala_symbol_get_name (VALA_SYMBOL (self->priv->_node)), vala_ccode_dynamic_signal_binding_signal_wrapper_id++), (self->priv->disconnect_wrapper_name = (g_free (self->priv->disconnect_wrapper_name), NULL)), _tmp1);
 		func = vala_ccode_function_new (self->priv->disconnect_wrapper_name, "void");
 		_tmp2 = NULL;
 		vala_ccode_function_add_parameter (func, (_tmp2 = vala_ccode_formal_parameter_new ("obj", "gpointer")));
