@@ -193,6 +193,8 @@ struct _ValaCCodeGenerator {
 	ValaDataType* uint_type;
 	ValaDataType* long_type;
 	ValaDataType* ulong_type;
+	ValaDataType* int8_type;
+	ValaDataType* uint8_type;
 	ValaDataType* int64_type;
 	ValaDataType* uint64_type;
 	ValaDataType* string_type;
@@ -221,10 +223,12 @@ struct _ValaCCodeGenerator {
 	gboolean requires_array_move;
 	gboolean dbus_glib_h_needed;
 };
+
 struct _ValaCCodeGeneratorClass {
 	ValaCodeGeneratorClass parent_class;
 };
 
+
 ValaCCodeGenerator* vala_ccode_generator_new (void);
 gboolean vala_ccode_generator_is_pure_ccode_expression (ValaCCodeGenerator* self, ValaCCodeExpression* cexpr);
 char* vala_ccode_generator_get_variable_cname (ValaCCodeGenerator* self, const char* name);
