@@ -70,6 +70,7 @@
 struct _ValaCCodeInterfaceBindingPrivate {
 	ValaInterface* _iface;
 };
+
 #define VALA_CCODE_INTERFACE_BINDING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_INTERFACE_BINDING, ValaCCodeInterfaceBindingPrivate))
 enum  {
 	VALA_CCODE_INTERFACE_BINDING_DUMMY_PROPERTY,
@@ -349,7 +350,7 @@ static void vala_ccode_interface_binding_add_interface_base_init_function (ValaC
 	(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
 	_tmp7 = NULL;
 	_tmp8 = NULL;
-	decl = (_tmp8 = vala_ccode_declaration_new ((_tmp7 = vala_data_type_get_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->bool_type, FALSE, FALSE))), (_tmp7 = (g_free (_tmp7), NULL)), _tmp8);
+	decl = (_tmp8 = vala_ccode_declaration_new ((_tmp7 = vala_data_type_get_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->bool_type))), (_tmp7 = (g_free (_tmp7), NULL)), _tmp8);
 	vala_ccode_declaration_set_modifiers (decl, vala_ccode_declaration_get_modifiers (decl) | (VALA_CCODE_MODIFIERS_STATIC));
 	_tmp10 = NULL;
 	_tmp9 = NULL;
