@@ -42,6 +42,7 @@
 #include <ccode/valaccodeassignment.h>
 #include <vala/valaarraylengthfield.h>
 #include <vala/valafield.h>
+#include <vala/valamember.h>
 #include <vala/valapointertype.h>
 #include <vala/valaconstant.h>
 #include <vala/valaproperty.h>
@@ -54,8 +55,8 @@
 #include <vala/valaformalparameter.h>
 #include <vala/valastruct.h>
 #include <vala/valasignal.h>
-#include <vala/valaclasstype.h>
-#include <vala/valainterfacetype.h>
+#include <vala/valaclassinstancetype.h>
+#include <vala/valainterfaceinstancetype.h>
 #include <vala/valavaluetype.h>
 #include <gobject/valaccodebinding.h>
 #include <gobject/valaccodemethodbinding.h>
@@ -66,6 +67,7 @@
 struct _ValaCCodeMemberAccessBindingPrivate {
 	ValaMemberAccess* _member_access;
 };
+
 #define VALA_CCODE_MEMBER_ACCESS_BINDING_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_MEMBER_ACCESS_BINDING, ValaCCodeMemberAccessBindingPrivate))
 enum  {
 	VALA_CCODE_MEMBER_ACCESS_BINDING_DUMMY_PROPERTY,
@@ -249,7 +251,7 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 				ValaField* f;
 				_tmp31 = NULL;
 				f = (_tmp31 = VALA_FIELD (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp31 == NULL ? NULL : g_object_ref (_tmp31)));
-				if (vala_field_get_instance (f)) {
+				if (vala_field_get_binding (f) == MEMBER_BINDING_INSTANCE) {
 					ValaDataType* _tmp32;
 					ValaDataType* instance_expression_type;
 					ValaDataType* instance_target_type;
@@ -295,96 +297,126 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 					(typed_inst == NULL ? NULL : (typed_inst = (g_object_unref (typed_inst), NULL)));
 					(inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL)));
 				} else {
-					ValaCCodeIdentifier* _tmp41;
-					char* _tmp40;
-					_tmp41 = NULL;
-					_tmp40 = NULL;
-					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp41 = vala_ccode_identifier_new ((_tmp40 = vala_field_get_cname (f))))));
-					(_tmp41 == NULL ? NULL : (_tmp41 = (g_object_unref (_tmp41), NULL)));
-					_tmp40 = (g_free (_tmp40), NULL);
+					if (vala_field_get_binding (f) == MEMBER_BINDING_CLASS) {
+						ValaClass* _tmp40;
+						ValaClass* cl;
+						ValaCCodeIdentifier* _tmp43;
+						char* _tmp42;
+						char* _tmp41;
+						ValaCCodeFunctionCall* _tmp44;
+						ValaCCodeFunctionCall* cast;
+						ValaCCodeIdentifier* _tmp45;
+						ValaCCodeMemberAccess* _tmp47;
+						char* _tmp46;
+						_tmp40 = NULL;
+						cl = (_tmp40 = VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (f))), (_tmp40 == NULL ? NULL : g_object_ref (_tmp40)));
+						_tmp43 = NULL;
+						_tmp42 = NULL;
+						_tmp41 = NULL;
+						_tmp44 = NULL;
+						cast = (_tmp44 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp43 = vala_ccode_identifier_new ((_tmp42 = g_strconcat ((_tmp41 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (cl), NULL)), "_CLASS", NULL)))))), (_tmp43 == NULL ? NULL : (_tmp43 = (g_object_unref (_tmp43), NULL))), (_tmp42 = (g_free (_tmp42), NULL)), (_tmp41 = (g_free (_tmp41), NULL)), _tmp44);
+						_tmp45 = NULL;
+						vala_ccode_function_call_add_argument (cast, VALA_CCODE_EXPRESSION ((_tmp45 = vala_ccode_identifier_new ("klass"))));
+						(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
+						_tmp47 = NULL;
+						_tmp46 = NULL;
+						vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp47 = vala_ccode_member_access_new_pointer (VALA_CCODE_EXPRESSION (cast), (_tmp46 = vala_field_get_cname (f))))));
+						(_tmp47 == NULL ? NULL : (_tmp47 = (g_object_unref (_tmp47), NULL)));
+						_tmp46 = (g_free (_tmp46), NULL);
+						(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
+						(cast == NULL ? NULL : (cast = (g_object_unref (cast), NULL)));
+					} else {
+						ValaCCodeIdentifier* _tmp49;
+						char* _tmp48;
+						_tmp49 = NULL;
+						_tmp48 = NULL;
+						vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp49 = vala_ccode_identifier_new ((_tmp48 = vala_field_get_cname (f))))));
+						(_tmp49 == NULL ? NULL : (_tmp49 = (g_object_unref (_tmp49), NULL)));
+						_tmp48 = (g_free (_tmp48), NULL);
+					}
 				}
 				if (vala_data_type_get_type_parameter (vala_field_get_type_reference (f)) != NULL && vala_data_type_get_type_parameter (vala_expression_get_static_type (VALA_EXPRESSION (expr))) == NULL) {
-					ValaCCodeExpression* _tmp42;
-					_tmp42 = NULL;
-					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp42 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (expr))), vala_expression_get_static_type (VALA_EXPRESSION (expr))))));
-					(_tmp42 == NULL ? NULL : (_tmp42 = (g_object_unref (_tmp42), NULL)));
+					ValaCCodeExpression* _tmp50;
+					_tmp50 = NULL;
+					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp50 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (expr))), vala_expression_get_static_type (VALA_EXPRESSION (expr))))));
+					(_tmp50 == NULL ? NULL : (_tmp50 = (g_object_unref (_tmp50), NULL)));
 				}
 				(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
 			} else {
 				if (VALA_IS_CONSTANT (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-					ValaConstant* _tmp43;
+					ValaConstant* _tmp51;
 					ValaConstant* c;
-					ValaCCodeIdentifier* _tmp45;
-					char* _tmp44;
-					_tmp43 = NULL;
-					c = (_tmp43 = VALA_CONSTANT (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp43 == NULL ? NULL : g_object_ref (_tmp43)));
-					_tmp45 = NULL;
-					_tmp44 = NULL;
-					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp45 = vala_ccode_identifier_new ((_tmp44 = vala_constant_get_cname (c))))));
-					(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
-					_tmp44 = (g_free (_tmp44), NULL);
+					ValaCCodeIdentifier* _tmp53;
+					char* _tmp52;
+					_tmp51 = NULL;
+					c = (_tmp51 = VALA_CONSTANT (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp51 == NULL ? NULL : g_object_ref (_tmp51)));
+					_tmp53 = NULL;
+					_tmp52 = NULL;
+					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp53 = vala_ccode_identifier_new ((_tmp52 = vala_constant_get_cname (c))))));
+					(_tmp53 == NULL ? NULL : (_tmp53 = (g_object_unref (_tmp53), NULL)));
+					_tmp52 = (g_free (_tmp52), NULL);
 					(c == NULL ? NULL : (c = (g_object_unref (c), NULL)));
 				} else {
 					if (VALA_IS_PROPERTY (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-						ValaProperty* _tmp46;
+						ValaProperty* _tmp54;
 						ValaProperty* prop;
-						_tmp46 = NULL;
-						prop = (_tmp46 = VALA_PROPERTY (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp46 == NULL ? NULL : g_object_ref (_tmp46)));
+						_tmp54 = NULL;
+						prop = (_tmp54 = VALA_PROPERTY (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp54 == NULL ? NULL : g_object_ref (_tmp54)));
 						if (vala_property_get_get_accessor (prop) != NULL && vala_property_accessor_get_automatic_body (vala_property_get_get_accessor (prop)) && VALA_SYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol) == vala_symbol_get_parent_symbol (VALA_SYMBOL (prop))) {
 							ValaCCodeExpression* inst;
-							ValaCCodeExpression* _tmp47;
-							ValaCCodeMemberAccess* _tmp49;
-							char* _tmp48;
+							ValaCCodeExpression* _tmp55;
+							ValaCCodeMemberAccess* _tmp57;
+							char* _tmp56;
 							inst = NULL;
-							_tmp47 = NULL;
-							inst = (_tmp47 = VALA_CCODE_EXPRESSION (vala_ccode_member_access_new_pointer (pub_inst, "priv")), (inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL))), _tmp47);
-							_tmp49 = NULL;
-							_tmp48 = NULL;
-							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp49 = vala_ccode_member_access_new_pointer (inst, (_tmp48 = vala_field_get_cname (vala_property_get_field (prop)))))));
-							(_tmp49 == NULL ? NULL : (_tmp49 = (g_object_unref (_tmp49), NULL)));
-							_tmp48 = (g_free (_tmp48), NULL);
+							_tmp55 = NULL;
+							inst = (_tmp55 = VALA_CCODE_EXPRESSION (vala_ccode_member_access_new_pointer (pub_inst, "priv")), (inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL))), _tmp55);
+							_tmp57 = NULL;
+							_tmp56 = NULL;
+							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp57 = vala_ccode_member_access_new_pointer (inst, (_tmp56 = vala_field_get_cname (vala_property_get_field (prop)))))));
+							(_tmp57 == NULL ? NULL : (_tmp57 = (g_object_unref (_tmp57), NULL)));
+							_tmp56 = (g_free (_tmp56), NULL);
 							(inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL)));
 						} else {
 							if (!vala_property_get_no_accessor_method (prop)) {
-								ValaProperty* _tmp50;
+								ValaProperty* _tmp58;
 								ValaProperty* base_property;
-								ValaTypesymbol* _tmp55;
+								ValaTypesymbol* _tmp63;
 								ValaTypesymbol* base_property_type;
-								ValaCCodeIdentifier* _tmp58;
-								char* _tmp57;
-								char* _tmp56;
-								ValaCCodeFunctionCall* _tmp59;
+								ValaCCodeIdentifier* _tmp66;
+								char* _tmp65;
+								char* _tmp64;
+								ValaCCodeFunctionCall* _tmp67;
 								ValaCCodeFunctionCall* ccall;
-								ValaDataType* _tmp60;
+								ValaDataType* _tmp68;
 								ValaDataType* instance_expression_type;
 								ValaDataType* instance_target_type;
 								ValaCCodeExpression* typed_pub_inst;
-								_tmp50 = NULL;
-								base_property = (_tmp50 = prop, (_tmp50 == NULL ? NULL : g_object_ref (_tmp50)));
+								_tmp58 = NULL;
+								base_property = (_tmp58 = prop, (_tmp58 == NULL ? NULL : g_object_ref (_tmp58)));
 								if (vala_property_get_base_property (prop) != NULL) {
-									ValaProperty* _tmp52;
-									ValaProperty* _tmp51;
-									_tmp52 = NULL;
-									_tmp51 = NULL;
-									base_property = (_tmp52 = (_tmp51 = vala_property_get_base_property (prop), (_tmp51 == NULL ? NULL : g_object_ref (_tmp51))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp52);
+									ValaProperty* _tmp60;
+									ValaProperty* _tmp59;
+									_tmp60 = NULL;
+									_tmp59 = NULL;
+									base_property = (_tmp60 = (_tmp59 = vala_property_get_base_property (prop), (_tmp59 == NULL ? NULL : g_object_ref (_tmp59))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp60);
 								} else {
 									if (vala_property_get_base_interface_property (prop) != NULL) {
-										ValaProperty* _tmp54;
-										ValaProperty* _tmp53;
-										_tmp54 = NULL;
-										_tmp53 = NULL;
-										base_property = (_tmp54 = (_tmp53 = vala_property_get_base_interface_property (prop), (_tmp53 == NULL ? NULL : g_object_ref (_tmp53))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp54);
+										ValaProperty* _tmp62;
+										ValaProperty* _tmp61;
+										_tmp62 = NULL;
+										_tmp61 = NULL;
+										base_property = (_tmp62 = (_tmp61 = vala_property_get_base_interface_property (prop), (_tmp61 == NULL ? NULL : g_object_ref (_tmp61))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp62);
 									}
 								}
-								_tmp55 = NULL;
-								base_property_type = (_tmp55 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (base_property))), (_tmp55 == NULL ? NULL : g_object_ref (_tmp55)));
-								_tmp58 = NULL;
-								_tmp57 = NULL;
-								_tmp56 = NULL;
-								_tmp59 = NULL;
-								ccall = (_tmp59 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp58 = vala_ccode_identifier_new ((_tmp57 = g_strdup_printf ("%s_get_%s", (_tmp56 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (base_property_type), NULL)), vala_symbol_get_name (VALA_SYMBOL (base_property)))))))), (_tmp58 == NULL ? NULL : (_tmp58 = (g_object_unref (_tmp58), NULL))), (_tmp57 = (g_free (_tmp57), NULL)), (_tmp56 = (g_free (_tmp56), NULL)), _tmp59);
-								_tmp60 = NULL;
-								instance_expression_type = (_tmp60 = base_type, (_tmp60 == NULL ? NULL : g_object_ref (_tmp60)));
+								_tmp63 = NULL;
+								base_property_type = (_tmp63 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (base_property))), (_tmp63 == NULL ? NULL : g_object_ref (_tmp63)));
+								_tmp66 = NULL;
+								_tmp65 = NULL;
+								_tmp64 = NULL;
+								_tmp67 = NULL;
+								ccall = (_tmp67 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp66 = vala_ccode_identifier_new ((_tmp65 = g_strdup_printf ("%s_get_%s", (_tmp64 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (base_property_type), NULL)), vala_symbol_get_name (VALA_SYMBOL (base_property)))))))), (_tmp66 == NULL ? NULL : (_tmp66 = (g_object_unref (_tmp66), NULL))), (_tmp65 = (g_free (_tmp65), NULL)), (_tmp64 = (g_free (_tmp64), NULL)), _tmp67);
+								_tmp68 = NULL;
+								instance_expression_type = (_tmp68 = base_type, (_tmp68 == NULL ? NULL : g_object_ref (_tmp68)));
 								instance_target_type = vala_ccode_generator_get_data_type_for_symbol (base_property_type);
 								typed_pub_inst = vala_ccode_generator_get_implicit_cast_expression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), pub_inst, instance_expression_type, instance_target_type);
 								vala_ccode_function_call_add_argument (ccall, typed_pub_inst);
@@ -394,14 +426,14 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 									ValaCCodeCommaExpression* ccomma;
 									ValaLocalVariable* temp_var;
 									ValaCCodeIdentifier* ctemp;
-									ValaCCodeUnaryExpression* _tmp61;
+									ValaCCodeUnaryExpression* _tmp69;
 									ccomma = vala_ccode_comma_expression_new ();
 									temp_var = vala_ccode_generator_get_temp_variable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_property_get_type_reference (base_property), TRUE, NULL);
 									ctemp = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_var)));
 									gee_collection_add (GEE_COLLECTION (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->temp_vars), temp_var);
-									_tmp61 = NULL;
-									vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp61 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
-									(_tmp61 == NULL ? NULL : (_tmp61 = (g_object_unref (_tmp61), NULL)));
+									_tmp69 = NULL;
+									vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp69 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
+									(_tmp69 == NULL ? NULL : (_tmp69 = (g_object_unref (_tmp69), NULL)));
 									vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ccall));
 									vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ctemp));
 									vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccomma));
@@ -418,40 +450,40 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 								(instance_target_type == NULL ? NULL : (instance_target_type = (g_object_unref (instance_target_type), NULL)));
 								(typed_pub_inst == NULL ? NULL : (typed_pub_inst = (g_object_unref (typed_pub_inst), NULL)));
 							} else {
-								ValaCCodeIdentifier* _tmp62;
-								ValaCCodeFunctionCall* _tmp63;
+								ValaCCodeIdentifier* _tmp70;
+								ValaCCodeFunctionCall* _tmp71;
 								ValaCCodeFunctionCall* ccall;
-								ValaCCodeIdentifier* _tmp64;
-								ValaCCodeFunctionCall* _tmp65;
+								ValaCCodeIdentifier* _tmp72;
+								ValaCCodeFunctionCall* _tmp73;
 								ValaCCodeFunctionCall* ccast;
-								ValaCCodeConstant* _tmp66;
+								ValaCCodeConstant* _tmp74;
 								ValaLocalVariable* temp_var;
 								ValaCCodeIdentifier* ctemp;
-								ValaCCodeUnaryExpression* _tmp67;
-								ValaCCodeConstant* _tmp68;
+								ValaCCodeUnaryExpression* _tmp75;
+								ValaCCodeConstant* _tmp76;
 								ValaCCodeCommaExpression* ccomma;
-								_tmp62 = NULL;
-								_tmp63 = NULL;
-								ccall = (_tmp63 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp62 = vala_ccode_identifier_new ("g_object_get")))), (_tmp62 == NULL ? NULL : (_tmp62 = (g_object_unref (_tmp62), NULL))), _tmp63);
-								_tmp64 = NULL;
-								_tmp65 = NULL;
-								ccast = (_tmp65 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp64 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp64 == NULL ? NULL : (_tmp64 = (g_object_unref (_tmp64), NULL))), _tmp65);
+								_tmp70 = NULL;
+								_tmp71 = NULL;
+								ccall = (_tmp71 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp70 = vala_ccode_identifier_new ("g_object_get")))), (_tmp70 == NULL ? NULL : (_tmp70 = (g_object_unref (_tmp70), NULL))), _tmp71);
+								_tmp72 = NULL;
+								_tmp73 = NULL;
+								ccast = (_tmp73 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp72 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp72 == NULL ? NULL : (_tmp72 = (g_object_unref (_tmp72), NULL))), _tmp73);
 								vala_ccode_function_call_add_argument (ccast, pub_inst);
 								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (ccast));
 								/* property name is second argument of g_object_get*/
-								_tmp66 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp66 = vala_property_get_canonical_cconstant (prop))));
-								(_tmp66 == NULL ? NULL : (_tmp66 = (g_object_unref (_tmp66), NULL)));
+								_tmp74 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp74 = vala_property_get_canonical_cconstant (prop))));
+								(_tmp74 == NULL ? NULL : (_tmp74 = (g_object_unref (_tmp74), NULL)));
 								/* we need a temporary variable to save the property value*/
 								temp_var = vala_ccode_generator_get_temp_variable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_expression_get_static_type (VALA_EXPRESSION (expr)), TRUE, NULL);
 								gee_list_insert (GEE_LIST (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->temp_vars), 0, temp_var);
 								ctemp = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_var)));
-								_tmp67 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp67 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
-								(_tmp67 == NULL ? NULL : (_tmp67 = (g_object_unref (_tmp67), NULL)));
-								_tmp68 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp68 = vala_ccode_constant_new ("NULL"))));
-								(_tmp68 == NULL ? NULL : (_tmp68 = (g_object_unref (_tmp68), NULL)));
+								_tmp75 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp75 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
+								(_tmp75 == NULL ? NULL : (_tmp75 = (g_object_unref (_tmp75), NULL)));
+								_tmp76 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp76 = vala_ccode_constant_new ("NULL"))));
+								(_tmp76 == NULL ? NULL : (_tmp76 = (g_object_unref (_tmp76), NULL)));
 								ccomma = vala_ccode_comma_expression_new ();
 								vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ccall));
 								vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ctemp));
@@ -466,69 +498,69 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 						(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
 					} else {
 						if (VALA_IS_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-							ValaEnumValue* _tmp69;
+							ValaEnumValue* _tmp77;
 							ValaEnumValue* ev;
-							ValaCCodeConstant* _tmp71;
-							char* _tmp70;
-							_tmp69 = NULL;
-							ev = (_tmp69 = VALA_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp69 == NULL ? NULL : g_object_ref (_tmp69)));
-							_tmp71 = NULL;
-							_tmp70 = NULL;
-							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp71 = vala_ccode_constant_new ((_tmp70 = vala_enum_value_get_cname (ev))))));
-							(_tmp71 == NULL ? NULL : (_tmp71 = (g_object_unref (_tmp71), NULL)));
-							_tmp70 = (g_free (_tmp70), NULL);
+							ValaCCodeConstant* _tmp79;
+							char* _tmp78;
+							_tmp77 = NULL;
+							ev = (_tmp77 = VALA_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp77 == NULL ? NULL : g_object_ref (_tmp77)));
+							_tmp79 = NULL;
+							_tmp78 = NULL;
+							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp79 = vala_ccode_constant_new ((_tmp78 = vala_enum_value_get_cname (ev))))));
+							(_tmp79 == NULL ? NULL : (_tmp79 = (g_object_unref (_tmp79), NULL)));
+							_tmp78 = (g_free (_tmp78), NULL);
 							(ev == NULL ? NULL : (ev = (g_object_unref (ev), NULL)));
 						} else {
 							if (VALA_IS_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-								ValaLocalVariable* _tmp72;
+								ValaLocalVariable* _tmp80;
 								ValaLocalVariable* local;
-								ValaCCodeIdentifier* _tmp74;
-								char* _tmp73;
-								_tmp72 = NULL;
-								local = (_tmp72 = VALA_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp72 == NULL ? NULL : g_object_ref (_tmp72)));
-								_tmp74 = NULL;
-								_tmp73 = NULL;
-								vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp74 = vala_ccode_identifier_new ((_tmp73 = vala_ccode_generator_get_variable_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_symbol_get_name (VALA_SYMBOL (local))))))));
-								(_tmp74 == NULL ? NULL : (_tmp74 = (g_object_unref (_tmp74), NULL)));
-								_tmp73 = (g_free (_tmp73), NULL);
+								ValaCCodeIdentifier* _tmp82;
+								char* _tmp81;
+								_tmp80 = NULL;
+								local = (_tmp80 = VALA_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp80 == NULL ? NULL : g_object_ref (_tmp80)));
+								_tmp82 = NULL;
+								_tmp81 = NULL;
+								vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp82 = vala_ccode_identifier_new ((_tmp81 = vala_ccode_generator_get_variable_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_symbol_get_name (VALA_SYMBOL (local))))))));
+								(_tmp82 == NULL ? NULL : (_tmp82 = (g_object_unref (_tmp82), NULL)));
+								_tmp81 = (g_free (_tmp81), NULL);
 								(local == NULL ? NULL : (local = (g_object_unref (local), NULL)));
 							} else {
 								if (VALA_IS_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-									ValaFormalParameter* _tmp75;
+									ValaFormalParameter* _tmp83;
 									ValaFormalParameter* p;
-									_tmp75 = NULL;
-									p = (_tmp75 = VALA_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp75 == NULL ? NULL : g_object_ref (_tmp75)));
+									_tmp83 = NULL;
+									p = (_tmp83 = VALA_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp83 == NULL ? NULL : g_object_ref (_tmp83)));
 									if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (p)), "this") == 0) {
 										vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (pub_inst));
 									} else {
-										ValaStruct* _tmp77;
-										ValaTypesymbol* _tmp76;
+										ValaStruct* _tmp85;
+										ValaTypesymbol* _tmp84;
 										ValaStruct* type_as_struct;
-										_tmp77 = NULL;
-										_tmp76 = NULL;
-										type_as_struct = (_tmp77 = (_tmp76 = vala_data_type_get_data_type (vala_formal_parameter_get_type_reference (p)), (VALA_IS_STRUCT (_tmp76) ? ((ValaStruct*) _tmp76) : NULL)), (_tmp77 == NULL ? NULL : g_object_ref (_tmp77)));
+										_tmp85 = NULL;
+										_tmp84 = NULL;
+										type_as_struct = (_tmp85 = (_tmp84 = vala_data_type_get_data_type (vala_formal_parameter_get_type_reference (p)), (VALA_IS_STRUCT (_tmp84) ? ((ValaStruct*) _tmp84) : NULL)), (_tmp85 == NULL ? NULL : g_object_ref (_tmp85)));
 										if (vala_formal_parameter_get_direction (p) != VALA_PARAMETER_DIRECTION_IN || (type_as_struct != NULL && !vala_struct_is_simple_type (type_as_struct))) {
-											ValaCCodeIdentifier* _tmp79;
-											char* _tmp78;
-											_tmp79 = NULL;
-											_tmp78 = NULL;
-											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp79 = vala_ccode_identifier_new ((_tmp78 = g_strdup_printf ("(*%s)", vala_symbol_get_name (VALA_SYMBOL (p))))))));
-											(_tmp79 == NULL ? NULL : (_tmp79 = (g_object_unref (_tmp79), NULL)));
-											_tmp78 = (g_free (_tmp78), NULL);
+											ValaCCodeIdentifier* _tmp87;
+											char* _tmp86;
+											_tmp87 = NULL;
+											_tmp86 = NULL;
+											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp87 = vala_ccode_identifier_new ((_tmp86 = g_strdup_printf ("(*%s)", vala_symbol_get_name (VALA_SYMBOL (p))))))));
+											(_tmp87 == NULL ? NULL : (_tmp87 = (g_object_unref (_tmp87), NULL)));
+											_tmp86 = (g_free (_tmp86), NULL);
 										} else {
 											/* Property setters of non simple structs shall replace all occurences
 											 of the "value" formal parameter with a dereferencing version of that
 											 parameter.*/
 											if (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor != NULL && vala_property_accessor_get_writable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor) && vala_property_accessor_get_value_parameter (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor) == p && vala_data_type_is_real_struct_type (vala_property_get_type_reference (vala_property_accessor_get_prop (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor)))) {
-												ValaCCodeIdentifier* _tmp80;
-												_tmp80 = NULL;
-												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp80 = vala_ccode_identifier_new ("(*value)"))));
-												(_tmp80 == NULL ? NULL : (_tmp80 = (g_object_unref (_tmp80), NULL)));
+												ValaCCodeIdentifier* _tmp88;
+												_tmp88 = NULL;
+												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp88 = vala_ccode_identifier_new ("(*value)"))));
+												(_tmp88 == NULL ? NULL : (_tmp88 = (g_object_unref (_tmp88), NULL)));
 											} else {
-												ValaCCodeIdentifier* _tmp81;
-												_tmp81 = NULL;
-												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp81 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (p))))));
-												(_tmp81 == NULL ? NULL : (_tmp81 = (g_object_unref (_tmp81), NULL)));
+												ValaCCodeIdentifier* _tmp89;
+												_tmp89 = NULL;
+												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp89 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (p))))));
+												(_tmp89 == NULL ? NULL : (_tmp89 = (g_object_unref (_tmp89), NULL)));
 											}
 										}
 										(type_as_struct == NULL ? NULL : (type_as_struct = (g_object_unref (type_as_struct), NULL)));
@@ -536,31 +568,31 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 									(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
 								} else {
 									if (VALA_IS_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-										ValaSignal* _tmp82;
+										ValaSignal* _tmp90;
 										ValaSignal* sig;
-										ValaTypesymbol* _tmp83;
+										ValaTypesymbol* _tmp91;
 										ValaTypesymbol* cl;
-										_tmp82 = NULL;
-										sig = (_tmp82 = VALA_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp82 == NULL ? NULL : g_object_ref (_tmp82)));
-										_tmp83 = NULL;
-										cl = (_tmp83 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (sig))), (_tmp83 == NULL ? NULL : g_object_ref (_tmp83)));
+										_tmp90 = NULL;
+										sig = (_tmp90 = VALA_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp90 == NULL ? NULL : g_object_ref (_tmp90)));
+										_tmp91 = NULL;
+										cl = (_tmp91 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (sig))), (_tmp91 == NULL ? NULL : g_object_ref (_tmp91)));
 										if (vala_signal_get_has_emitter (sig)) {
-											ValaCCodeIdentifier* _tmp86;
-											char* _tmp85;
-											char* _tmp84;
-											ValaCCodeFunctionCall* _tmp87;
+											ValaCCodeIdentifier* _tmp94;
+											char* _tmp93;
+											char* _tmp92;
+											ValaCCodeFunctionCall* _tmp95;
 											ValaCCodeFunctionCall* ccall;
-											ValaDataType* _tmp88;
+											ValaDataType* _tmp96;
 											ValaDataType* instance_expression_type;
 											ValaDataType* instance_target_type;
 											ValaCCodeExpression* typed_pub_inst;
-											_tmp86 = NULL;
-											_tmp85 = NULL;
-											_tmp84 = NULL;
-											_tmp87 = NULL;
-											ccall = (_tmp87 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp86 = vala_ccode_identifier_new ((_tmp85 = g_strdup_printf ("%s_%s", (_tmp84 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (cl), NULL)), vala_symbol_get_name (VALA_SYMBOL (sig)))))))), (_tmp86 == NULL ? NULL : (_tmp86 = (g_object_unref (_tmp86), NULL))), (_tmp85 = (g_free (_tmp85), NULL)), (_tmp84 = (g_free (_tmp84), NULL)), _tmp87);
-											_tmp88 = NULL;
-											instance_expression_type = (_tmp88 = base_type, (_tmp88 == NULL ? NULL : g_object_ref (_tmp88)));
+											_tmp94 = NULL;
+											_tmp93 = NULL;
+											_tmp92 = NULL;
+											_tmp95 = NULL;
+											ccall = (_tmp95 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp94 = vala_ccode_identifier_new ((_tmp93 = g_strdup_printf ("%s_%s", (_tmp92 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (cl), NULL)), vala_symbol_get_name (VALA_SYMBOL (sig)))))))), (_tmp94 == NULL ? NULL : (_tmp94 = (g_object_unref (_tmp94), NULL))), (_tmp93 = (g_free (_tmp93), NULL)), (_tmp92 = (g_free (_tmp92), NULL)), _tmp95);
+											_tmp96 = NULL;
+											instance_expression_type = (_tmp96 = base_type, (_tmp96 == NULL ? NULL : g_object_ref (_tmp96)));
 											instance_target_type = vala_ccode_generator_get_data_type_for_symbol (cl);
 											typed_pub_inst = vala_ccode_generator_get_implicit_cast_expression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), pub_inst, instance_expression_type, instance_target_type);
 											vala_ccode_function_call_add_argument (ccall, typed_pub_inst);
@@ -570,25 +602,25 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 											(instance_target_type == NULL ? NULL : (instance_target_type = (g_object_unref (instance_target_type), NULL)));
 											(typed_pub_inst == NULL ? NULL : (typed_pub_inst = (g_object_unref (typed_pub_inst), NULL)));
 										} else {
-											ValaCCodeIdentifier* _tmp89;
-											ValaCCodeFunctionCall* _tmp90;
+											ValaCCodeIdentifier* _tmp97;
+											ValaCCodeFunctionCall* _tmp98;
 											ValaCCodeFunctionCall* ccall;
-											ValaCCodeIdentifier* _tmp91;
-											ValaCCodeFunctionCall* _tmp92;
+											ValaCCodeIdentifier* _tmp99;
+											ValaCCodeFunctionCall* _tmp100;
 											ValaCCodeFunctionCall* ccast;
-											ValaCCodeConstant* _tmp93;
-											_tmp89 = NULL;
-											_tmp90 = NULL;
-											ccall = (_tmp90 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp89 = vala_ccode_identifier_new ("g_signal_emit_by_name")))), (_tmp89 == NULL ? NULL : (_tmp89 = (g_object_unref (_tmp89), NULL))), _tmp90);
+											ValaCCodeConstant* _tmp101;
+											_tmp97 = NULL;
+											_tmp98 = NULL;
+											ccall = (_tmp98 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp97 = vala_ccode_identifier_new ("g_signal_emit_by_name")))), (_tmp97 == NULL ? NULL : (_tmp97 = (g_object_unref (_tmp97), NULL))), _tmp98);
 											/* FIXME: use C cast if debugging disabled*/
-											_tmp91 = NULL;
-											_tmp92 = NULL;
-											ccast = (_tmp92 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp91 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp91 == NULL ? NULL : (_tmp91 = (g_object_unref (_tmp91), NULL))), _tmp92);
+											_tmp99 = NULL;
+											_tmp100 = NULL;
+											ccast = (_tmp100 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp99 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp99 == NULL ? NULL : (_tmp99 = (g_object_unref (_tmp99), NULL))), _tmp100);
 											vala_ccode_function_call_add_argument (ccast, pub_inst);
 											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (ccast));
-											_tmp93 = NULL;
-											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp93 = vala_signal_get_canonical_cconstant (sig))));
-											(_tmp93 == NULL ? NULL : (_tmp93 = (g_object_unref (_tmp93), NULL)));
+											_tmp101 = NULL;
+											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp101 = vala_signal_get_canonical_cconstant (sig))));
+											(_tmp101 == NULL ? NULL : (_tmp101 = (g_object_unref (_tmp101), NULL)));
 											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccall));
 											(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 											(ccast == NULL ? NULL : (ccast = (g_object_unref (ccast), NULL)));
@@ -627,12 +659,12 @@ static void vala_ccode_member_access_binding_real_emit (ValaCCodeBinding* base)
 			if (VALA_IS_CLASS (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol)) {
 				ValaDataType* _tmp2;
 				_tmp2 = NULL;
-				base_type = (_tmp2 = VALA_DATA_TYPE (vala_class_type_new (VALA_CLASS (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol))), (base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL))), _tmp2);
+				base_type = (_tmp2 = VALA_DATA_TYPE (vala_class_instance_type_new (VALA_CLASS (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol))), (base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL))), _tmp2);
 			} else {
 				if (VALA_IS_INTERFACE (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol)) {
 					ValaDataType* _tmp3;
 					_tmp3 = NULL;
-					base_type = (_tmp3 = VALA_DATA_TYPE (vala_interface_type_new (VALA_INTERFACE (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol))), (base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL))), _tmp3);
+					base_type = (_tmp3 = VALA_DATA_TYPE (vala_interface_instance_type_new (VALA_INTERFACE (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol))), (base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL))), _tmp3);
 				} else {
 					ValaDataType* _tmp4;
 					ValaCCodeExpression* _tmp5;
