@@ -1,6 +1,6 @@
 /* valaclassregisterfunction.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -40,6 +40,7 @@
 struct _ValaClassRegisterFunctionPrivate {
 	ValaClass* _class_reference;
 };
+
 #define VALA_CLASS_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CLASS_REGISTER_FUNCTION, ValaClassRegisterFunctionPrivate))
 enum  {
 	VALA_CLASS_REGISTER_FUNCTION_DUMMY_PROPERTY,
@@ -99,7 +100,15 @@ static char* vala_class_register_function_real_get_type_struct_name (ValaTypeReg
 static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
 	self = VALA_CLASS_REGISTER_FUNCTION (base);
-	return g_strdup ("NULL");
+	if (vala_class_get_class_constructor (self->priv->_class_reference) != NULL) {
+		char* _tmp0;
+		char* _tmp1;
+		_tmp0 = NULL;
+		_tmp1 = NULL;
+		return (_tmp1 = g_strdup_printf ("%s_base_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_class_reference), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	} else {
+		return g_strdup ("NULL");
+	}
 }
 
 
