@@ -27,11 +27,12 @@
 #include <vala/valascope.h>
 #include <vala/valacodenode.h>
 #include <vala/valadatatype.h>
-#include <vala/valainterfacetype.h>
+#include <vala/valainterfaceinstancetype.h>
 #include <gee/collection.h>
-#include <vala/valaclasstype.h>
+#include <vala/valaclassinstancetype.h>
 #include <vala/valadelegatetype.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valamember.h>
 #include <gobject/valaccodegenerator.h>
 
 
@@ -43,6 +44,7 @@ struct _ValaGIdlWriterPrivate {
 	gint indent;
 	ValaTypesymbol* gobject_type;
 };
+
 #define VALA_GIDL_WRITER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_GIDL_WRITER, ValaGIdlWriterPrivate))
 enum  {
 	VALA_GIDL_WRITER_DUMMY_PROPERTY
@@ -173,12 +175,12 @@ static void vala_gidl_writer_real_visit_class (ValaCodeVisitor* base, ValaClass*
 				ValaDataType* base_type;
 				base_type = ((ValaDataType*) gee_iterator_get (base_type_it));
 				{
-					ValaInterfaceType* _tmp4;
+					ValaInterfaceInstanceType* _tmp4;
 					ValaDataType* _tmp3;
-					ValaInterfaceType* iface_type;
+					ValaInterfaceInstanceType* iface_type;
 					_tmp4 = NULL;
 					_tmp3 = NULL;
-					iface_type = (_tmp4 = (_tmp3 = base_type, (VALA_IS_INTERFACE_TYPE (_tmp3) ? ((ValaInterfaceType*) _tmp3) : NULL)), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
+					iface_type = (_tmp4 = (_tmp3 = base_type, (VALA_IS_INTERFACE_INSTANCE_TYPE (_tmp3) ? ((ValaInterfaceInstanceType*) _tmp3) : NULL)), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
 					if (iface_type != NULL) {
 						char* _tmp5;
 						if (first) {
@@ -189,7 +191,7 @@ static void vala_gidl_writer_real_visit_class (ValaCodeVisitor* base, ValaClass*
 						}
 						vala_gidl_writer_write_indent (self);
 						_tmp5 = NULL;
-						fprintf (self->priv->stream, "<interface name=\"%s\"/>\n", (_tmp5 = vala_symbol_get_full_name (VALA_SYMBOL (vala_interface_type_get_interface_symbol (iface_type)))));
+						fprintf (self->priv->stream, "<interface name=\"%s\"/>\n", (_tmp5 = vala_symbol_get_full_name (VALA_SYMBOL (vala_interface_instance_type_get_interface_symbol (iface_type)))));
 						_tmp5 = (g_free (_tmp5), NULL);
 					}
 					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
@@ -283,30 +285,30 @@ static void vala_gidl_writer_real_visit_interface (ValaCodeVisitor* base, ValaIn
 				ValaDataType* base_type;
 				base_type = ((ValaDataType*) gee_iterator_get (base_type_it));
 				{
-					ValaClassType* _tmp5;
+					ValaClassInstanceType* _tmp5;
 					ValaDataType* _tmp4;
-					ValaClassType* class_type;
-					ValaInterfaceType* _tmp7;
+					ValaClassInstanceType* class_type;
+					ValaInterfaceInstanceType* _tmp7;
 					ValaDataType* _tmp6;
-					ValaInterfaceType* iface_type;
+					ValaInterfaceInstanceType* iface_type;
 					_tmp5 = NULL;
 					_tmp4 = NULL;
-					class_type = (_tmp5 = (_tmp4 = base_type, (VALA_IS_CLASS_TYPE (_tmp4) ? ((ValaClassType*) _tmp4) : NULL)), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5)));
+					class_type = (_tmp5 = (_tmp4 = base_type, (VALA_IS_CLASS_INSTANCE_TYPE (_tmp4) ? ((ValaClassInstanceType*) _tmp4) : NULL)), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5)));
 					_tmp7 = NULL;
 					_tmp6 = NULL;
-					iface_type = (_tmp7 = (_tmp6 = base_type, (VALA_IS_INTERFACE_TYPE (_tmp6) ? ((ValaInterfaceType*) _tmp6) : NULL)), (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
+					iface_type = (_tmp7 = (_tmp6 = base_type, (VALA_IS_INTERFACE_INSTANCE_TYPE (_tmp6) ? ((ValaInterfaceInstanceType*) _tmp6) : NULL)), (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
 					if (class_type != NULL) {
 						char* _tmp8;
 						vala_gidl_writer_write_indent (self);
 						_tmp8 = NULL;
-						fprintf (self->priv->stream, "<object name=\"%s\"/>\n", (_tmp8 = vala_symbol_get_full_name (VALA_SYMBOL (vala_class_type_get_class_symbol (class_type)))));
+						fprintf (self->priv->stream, "<object name=\"%s\"/>\n", (_tmp8 = vala_symbol_get_full_name (VALA_SYMBOL (vala_class_instance_type_get_class_symbol (class_type)))));
 						_tmp8 = (g_free (_tmp8), NULL);
 					} else {
 						if (iface_type != NULL) {
 							char* _tmp9;
 							vala_gidl_writer_write_indent (self);
 							_tmp9 = NULL;
-							fprintf (self->priv->stream, "<interface name=\"%s\"/>\n", (_tmp9 = vala_symbol_get_full_name (VALA_SYMBOL (vala_interface_type_get_interface_symbol (iface_type)))));
+							fprintf (self->priv->stream, "<interface name=\"%s\"/>\n", (_tmp9 = vala_symbol_get_full_name (VALA_SYMBOL (vala_interface_instance_type_get_interface_symbol (iface_type)))));
 							_tmp9 = (g_free (_tmp9), NULL);
 						} else {
 							g_assert_not_reached ();
@@ -448,7 +450,7 @@ static char* vala_gidl_writer_get_gidl_type_name (ValaGIdlWriter* self, ValaData
 	g_return_val_if_fail (VALA_IS_GIDL_WRITER (self), NULL);
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
 	/* workaround to get GIDL-specific type name*/
-	gidl_type = vala_data_type_get_cname (type, FALSE, FALSE);
+	gidl_type = vala_data_type_get_cname (type);
 	if (vala_data_type_get_data_type (type) != NULL) {
 		char* cname;
 		cname = vala_typesymbol_get_cname (vala_data_type_get_data_type (type), FALSE);
@@ -473,7 +475,7 @@ static char* vala_gidl_writer_get_gidl_type_name (ValaGIdlWriter* self, ValaData
 			char* cname;
 			_tmp4 = NULL;
 			dt = (_tmp4 = VALA_DELEGATE_TYPE (type), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
-			cname = vala_data_type_get_cname (VALA_DATA_TYPE (dt), FALSE, FALSE);
+			cname = vala_data_type_get_cname (VALA_DATA_TYPE (dt));
 			if (g_str_has_prefix (gidl_type, cname)) {
 				char* _tmp8;
 				char* _tmp7;
@@ -604,7 +606,7 @@ static void vala_gidl_writer_real_visit_method (ValaCodeVisitor* base, ValaMetho
 	fprintf (self->priv->stream, ">\n");
 	self->priv->indent++;
 	instance_type = NULL;
-	if (vala_method_get_instance (m)) {
+	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		ValaDataType* _tmp1;
 		_tmp1 = NULL;
 		instance_type = (_tmp1 = vala_ccode_generator_get_data_type_for_symbol (VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (m)))), (instance_type == NULL ? NULL : (instance_type = (g_object_unref (instance_type), NULL))), _tmp1);
