@@ -18,26 +18,30 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #include <gobject/valainterfaceregisterfunction.h>
-#include <vala/valatypereference.h>
+#include <vala/valadatatype.h>
 #include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodeidentifier.h>
 #include <ccode/valaccodeexpression.h>
 #include <ccode/valaccodeexpressionstatement.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaInterfaceRegisterFunctionPrivate {
 	ValaInterface* _interface_reference;
 };
+
 #define VALA_INTERFACE_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE_REGISTER_FUNCTION, ValaInterfaceRegisterFunctionPrivate))
 enum  {
 	VALA_INTERFACE_REGISTER_FUNCTION_DUMMY_PROPERTY,
 	VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE
 };
-static ValaDataType* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
+static ValaTypesymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base);
@@ -50,6 +54,7 @@ static gpointer vala_interface_register_function_parent_class = NULL;
 static void vala_interface_register_function_dispose (GObject * obj);
 
 
+
 ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface) {
 	ValaInterfaceRegisterFunction * self;
 	g_return_val_if_fail (VALA_IS_INTERFACE (iface), NULL);
@@ -59,17 +64,19 @@ ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterfa
 }
 
 
-static ValaDataType* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
+static ValaTypesymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
+	ValaInterface* _tmp0;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
-	return VALA_DATA_TYPE (g_object_ref (vala_interface_register_function_get_interface_reference (self)));
+	_tmp0 = NULL;
+	return VALA_TYPESYMBOL ((_tmp0 = self->priv->_interface_reference, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
 }
 
 
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
-	return vala_interface_get_type_cname (vala_interface_register_function_get_interface_reference (self));
+	return vala_interface_get_type_cname (self->priv->_interface_reference);
 }
 
 
@@ -80,7 +87,7 @@ static char* vala_interface_register_function_real_get_base_init_func_name (Vala
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s_base_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strdup_printf ("%s_base_init", (_tmp0 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_interface_reference), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -115,7 +122,7 @@ static char* vala_interface_register_function_real_get_parent_type_name (ValaTyp
 static ValaSymbolAccessibility vala_interface_register_function_real_get_accessibility (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
-	return vala_symbol_get_access (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)));
+	return vala_symbol_get_access (VALA_SYMBOL (self->priv->_interface_reference));
 }
 
 
@@ -124,17 +131,18 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 	ValaCCodeFragment* frag;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
 	frag = vala_ccode_fragment_new ();
+	/* register all prerequisites */
 	{
 		GeeCollection* prereq_ref_collection;
 		GeeIterator* prereq_ref_it;
-		prereq_ref_collection = vala_interface_get_prerequisites (vala_interface_register_function_get_interface_reference (self));
+		prereq_ref_collection = vala_interface_get_prerequisites (self->priv->_interface_reference);
 		prereq_ref_it = gee_iterable_iterator (GEE_ITERABLE (prereq_ref_collection));
 		while (gee_iterator_next (prereq_ref_it)) {
-			ValaTypeReference* prereq_ref;
-			prereq_ref = gee_iterator_get (prereq_ref_it);
+			ValaDataType* prereq_ref;
+			prereq_ref = ((ValaDataType*) gee_iterator_get (prereq_ref_it));
 			{
-				ValaDataType* _tmp0;
-				ValaDataType* prereq;
+				ValaTypesymbol* _tmp0;
+				ValaTypesymbol* prereq;
 				ValaCCodeIdentifier* _tmp1;
 				ValaCCodeFunctionCall* _tmp2;
 				ValaCCodeFunctionCall* func;
@@ -144,24 +152,23 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 				ValaCCodeIdentifier* _tmp7;
 				char* _tmp6;
 				ValaCCodeExpressionStatement* _tmp8;
-				/* register all prerequisites */
 				_tmp0 = NULL;
-				prereq = (_tmp0 = vala_type_reference_get_data_type (prereq_ref), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+				prereq = (_tmp0 = vala_data_type_get_data_type (prereq_ref), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 				_tmp1 = NULL;
 				_tmp2 = NULL;
 				func = (_tmp2 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp1 = vala_ccode_identifier_new ("g_type_interface_add_prerequisite")))), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
 				_tmp5 = NULL;
 				_tmp4 = NULL;
 				_tmp3 = NULL;
-				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = g_strdup_printf ("%s_type_id", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)), NULL))))))));
+				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp5 = vala_ccode_identifier_new ((_tmp4 = g_strdup_printf ("%s_type_id", (_tmp3 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_interface_reference), NULL))))))));
 				(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
-				(_tmp4 = (g_free (_tmp4), NULL));
-				(_tmp3 = (g_free (_tmp3), NULL));
+				_tmp4 = (g_free (_tmp4), NULL);
+				_tmp3 = (g_free (_tmp3), NULL);
 				_tmp7 = NULL;
 				_tmp6 = NULL;
-				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_data_type_get_type_id (prereq))))));
+				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_typesymbol_get_type_id (prereq))))));
 				(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
-				(_tmp6 = (g_free (_tmp6), NULL));
+				_tmp6 = (g_free (_tmp6), NULL);
 				_tmp8 = NULL;
 				vala_ccode_fragment_append (frag, VALA_CCODE_NODE ((_tmp8 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (func)))));
 				(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
@@ -174,7 +181,6 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 		(prereq_ref_it == NULL ? NULL : (prereq_ref_it = (g_object_unref (prereq_ref_it), NULL)));
 	}
 	return frag;
-	(frag == NULL ? NULL : (frag = (g_object_unref (frag), NULL)));
 }
 
 
@@ -224,15 +230,15 @@ static void vala_interface_register_function_class_init (ValaInterfaceRegisterFu
 	G_OBJECT_CLASS (klass)->get_property = vala_interface_register_function_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_interface_register_function_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_interface_register_function_dispose;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_interface_register_function_real_get_type_declaration;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_struct_name = vala_interface_register_function_real_get_type_struct_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_base_init_func_name = vala_interface_register_function_real_get_base_init_func_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_class_init_func_name = vala_interface_register_function_real_get_class_init_func_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_instance_struct_size = vala_interface_register_function_real_get_instance_struct_size;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_instance_init_func_name = vala_interface_register_function_real_get_instance_init_func_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_parent_type_name = vala_interface_register_function_real_get_parent_type_name;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_interface_register_function_real_get_accessibility;
-	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_interface_register_function_real_get_type_interface_init_statements;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_interface_register_function_real_get_type_declaration;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_struct_name = vala_interface_register_function_real_get_type_struct_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_base_init_func_name = vala_interface_register_function_real_get_base_init_func_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_class_init_func_name = vala_interface_register_function_real_get_class_init_func_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_instance_struct_size = vala_interface_register_function_real_get_instance_struct_size;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_instance_init_func_name = vala_interface_register_function_real_get_instance_init_func_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_parent_type_name = vala_interface_register_function_real_get_parent_type_name;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_interface_register_function_real_get_accessibility;
+	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_interface_register_function_real_get_type_interface_init_statements;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE, g_param_spec_object ("interface-reference", "interface-reference", "interface-reference", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -253,7 +259,7 @@ GType vala_interface_register_function_get_type (void) {
 	static GType vala_interface_register_function_type_id = 0;
 	if (G_UNLIKELY (vala_interface_register_function_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceRegisterFunction), 0, (GInstanceInitFunc) vala_interface_register_function_init };
-		vala_interface_register_function_type_id = g_type_register_static (VALA_TYPE_TYPE_REGISTER_FUNCTION, "ValaInterfaceRegisterFunction", &g_define_type_info, 0);
+		vala_interface_register_function_type_id = g_type_register_static (VALA_TYPE_TYPEREGISTER_FUNCTION, "ValaInterfaceRegisterFunction", &g_define_type_info, 0);
 	}
 	return vala_interface_register_function_type_id;
 }
