@@ -21,8 +21,8 @@
  */
 
 #include <vala/valaarraymovemethod.h>
-#include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valasymbol.h>
 
 
 
@@ -41,10 +41,10 @@ static gpointer vala_array_move_method_parent_class = NULL;
  */
 ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference) {
 	ValaArrayMoveMethod * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ARRAY_MOVE_METHOD, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), "move");
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), "move");
 	return self;
 }
 
