@@ -21,9 +21,12 @@
  */
 
 #include <vala/valaarrayresizemethod.h>
-#include <vala/valasourcereference.h>
+#include <vala/valacodenode.h>
 #include <vala/valasymbol.h>
 
+
+
+
 enum  {
 	VALA_ARRAY_RESIZE_METHOD_DUMMY_PROPERTY
 };
@@ -31,6 +34,7 @@ static GObject * vala_array_resize_method_constructor (GType type, guint n_const
 static gpointer vala_array_resize_method_parent_class = NULL;
 
 
+
 /**
  * Creates a new array resize method.
  *
@@ -38,10 +42,10 @@ static gpointer vala_array_resize_method_parent_class = NULL;
  */
 ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source_reference) {
 	ValaArrayResizeMethod * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ARRAY_RESIZE_METHOD, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), "resize");
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), "resize");
 	return self;
 }
 
