@@ -35,6 +35,7 @@ static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st);
 static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface);
 static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en);
+static void vala_attribute_processor_real_visit_enum_value (ValaCodeVisitor* base, ValaEnumValue* ev);
 static void vala_attribute_processor_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* edomain);
 static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
 static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m);
@@ -124,6 +125,15 @@ static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, Val
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
 	g_return_if_fail (VALA_IS_ENUM (en));
 	vala_enum_process_attributes (en);
+	vala_code_node_accept_children (VALA_CODE_NODE (en), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_attribute_processor_real_visit_enum_value (ValaCodeVisitor* base, ValaEnumValue* ev) {
+	ValaAttributeProcessor * self;
+	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	g_return_if_fail (VALA_IS_ENUM_VALUE (ev));
+	vala_enum_value_process_attributes (ev);
 }
 
 
@@ -221,6 +231,7 @@ static void vala_attribute_processor_class_init (ValaAttributeProcessorClass * k
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_attribute_processor_real_visit_struct;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_attribute_processor_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_attribute_processor_real_visit_enum;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_enum_value = vala_attribute_processor_real_visit_enum_value;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_error_domain = vala_attribute_processor_real_visit_error_domain;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method = vala_attribute_processor_real_visit_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_creation_method = vala_attribute_processor_real_visit_creation_method;
