@@ -48,21 +48,26 @@ struct _ValaCatchClause {
 	ValaCodeNode parent_instance;
 	ValaCatchClausePrivate * priv;
 };
+
 struct _ValaCatchClauseClass {
 	ValaCodeNodeClass parent_class;
 };
 
-ValaCatchClause* vala_catch_clause_new (ValaDataType* type_reference, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference);
-ValaDataType* vala_catch_clause_get_type_reference (ValaCatchClause* self);
-void vala_catch_clause_set_type_reference (ValaCatchClause* self, ValaDataType* value);
+
+ValaCatchClause* vala_catch_clause_new (ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference);
+ValaDataType* vala_catch_clause_get_error_type (ValaCatchClause* self);
+void vala_catch_clause_set_error_type (ValaCatchClause* self, ValaDataType* value);
 char* vala_catch_clause_get_variable_name (ValaCatchClause* self);
 void vala_catch_clause_set_variable_name (ValaCatchClause* self, const char* value);
 ValaBlock* vala_catch_clause_get_body (ValaCatchClause* self);
 void vala_catch_clause_set_body (ValaCatchClause* self, ValaBlock* value);
-ValaVariableDeclarator* vala_catch_clause_get_variable_declarator (ValaCatchClause* self);
-void vala_catch_clause_set_variable_declarator (ValaCatchClause* self, ValaVariableDeclarator* value);
+ValaLocalVariable* vala_catch_clause_get_error_variable (ValaCatchClause* self);
+void vala_catch_clause_set_error_variable (ValaCatchClause* self, ValaLocalVariable* value);
+char* vala_catch_clause_get_clabel_name (ValaCatchClause* self);
+void vala_catch_clause_set_clabel_name (ValaCatchClause* self, const char* value);
 GType vala_catch_clause_get_type (void);
 
+
 G_END_DECLS
 
 #endif
