@@ -39,7 +39,6 @@
 #include <vala/valastatement.h>
 #include <vala/valacatchclause.h>
 #include <vala/valadatatype.h>
-#include <vala/valaerrordomain.h>
 #include <vala/valaerrorcode.h>
 
 
@@ -58,17 +57,20 @@ struct _ValaCFGBuilderJumpTarget {
 	GObject parent_instance;
 	ValaCFGBuilderJumpTargetPrivate * priv;
 };
+
 struct _ValaCFGBuilderJumpTargetClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _ValaCFGBuilderPrivate {
 	ValaCodeContext* context;
 	ValaBasicBlock* current_block;
 	gboolean unreachable_reported;
 	GeeList* jump_stack;
 };
+
 #define VALA_CFG_BUILDER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CFG_BUILDER, ValaCFGBuilderPrivate))
 enum  {
 	VALA_CFG_BUILDER_DUMMY_PROPERTY
@@ -78,6 +80,7 @@ static void vala_cfg_builder_real_visit_class (ValaCodeVisitor* base, ValaClass*
 static void vala_cfg_builder_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st);
 static void vala_cfg_builder_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface);
 static void vala_cfg_builder_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en);
+static void vala_cfg_builder_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* ed);
 static void vala_cfg_builder_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
 static void vala_cfg_builder_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop);
 static void vala_cfg_builder_real_visit_property_accessor (ValaCodeVisitor* base, ValaPropertyAccessor* acc);
@@ -110,6 +113,7 @@ struct _ValaCFGBuilderJumpTargetPrivate {
 	ValaBasicBlock* _last_block;
 	ValaCatchClause* _catch_clause;
 };
+
 #define VALA_CFG_BUILDER_JUMP_TARGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_CFG_BUILDER_TYPE_JUMP_TARGET, ValaCFGBuilderJumpTargetPrivate))
 enum  {
 	VALA_CFG_BUILDER_JUMP_TARGET_DUMMY_PROPERTY,
@@ -242,6 +246,14 @@ static void vala_cfg_builder_real_visit_enum (ValaCodeVisitor* base, ValaEnum* e
 }
 
 
+static void vala_cfg_builder_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* ed) {
+	ValaCFGBuilder * self;
+	self = VALA_CFG_BUILDER (base);
+	g_return_if_fail (VALA_IS_ERROR_DOMAIN (ed));
+	vala_code_node_accept_children (VALA_CODE_NODE (ed), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_cfg_builder_real_visit_method (ValaCodeVisitor* base, ValaMethod* m) {
 	ValaCFGBuilder * self;
 	ValaBasicBlock* _tmp0;
@@ -1594,6 +1606,7 @@ static void vala_cfg_builder_class_init (ValaCFGBuilderClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_cfg_builder_real_visit_struct;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_cfg_builder_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_cfg_builder_real_visit_enum;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_error_domain = vala_cfg_builder_real_visit_error_domain;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method = vala_cfg_builder_real_visit_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_property = vala_cfg_builder_real_visit_property;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_property_accessor = vala_cfg_builder_real_visit_property_accessor;
