@@ -29,12 +29,14 @@
 struct _ValaClassTypePrivate {
 	ValaClass* _class_symbol;
 };
+
 #define VALA_CLASS_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CLASS_TYPE, ValaClassTypePrivate))
 enum  {
 	VALA_CLASS_TYPE_DUMMY_PROPERTY,
 	VALA_CLASS_TYPE_CLASS_SYMBOL
 };
 static ValaDataType* vala_class_type_real_copy (ValaDataType* base);
+static char* vala_class_type_real_get_cname (ValaDataType* base);
 static gpointer vala_class_type_parent_class = NULL;
 static void vala_class_type_dispose (GObject * obj);
 
@@ -45,7 +47,6 @@ ValaClassType* vala_class_type_new (ValaClass* class_symbol) {
 	g_return_val_if_fail (VALA_IS_CLASS (class_symbol), NULL);
 	self = g_object_newv (VALA_TYPE_CLASS_TYPE, 0, NULL);
 	vala_class_type_set_class_symbol (self, class_symbol);
-	vala_data_type_set_data_type (VALA_DATA_TYPE (self), VALA_TYPESYMBOL (class_symbol));
 	return self;
 }
 
@@ -84,6 +85,17 @@ static ValaDataType* vala_class_type_real_copy (ValaDataType* base) {
 }
 
 
+static char* vala_class_type_real_get_cname (ValaDataType* base) {
+	ValaClassType * self;
+	char* _tmp0;
+	char* _tmp1;
+	self = VALA_CLASS_TYPE (base);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%sClass*", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_class_symbol), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+}
+
+
 ValaClass* vala_class_type_get_class_symbol (ValaClassType* self) {
 	g_return_val_if_fail (VALA_IS_CLASS_TYPE (self), NULL);
 	return self->priv->_class_symbol;
@@ -131,6 +143,7 @@ static void vala_class_type_class_init (ValaClassTypeClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_class_type_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_class_type_dispose;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_class_type_real_copy;
+	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_class_type_real_get_cname;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CLASS_TYPE_CLASS_SYMBOL, g_param_spec_object ("class-symbol", "class-symbol", "class-symbol", VALA_TYPE_CLASS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
