@@ -32,14 +32,15 @@
 struct _ValaConstructorPrivate {
 	ValaBlock* _body;
 	ValaFormalParameter* _this_parameter;
-	gboolean _instance;
+	MemberBinding _binding;
 };
+
 #define VALA_CONSTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CONSTRUCTOR, ValaConstructorPrivate))
 enum  {
 	VALA_CONSTRUCTOR_DUMMY_PROPERTY,
 	VALA_CONSTRUCTOR_BODY,
 	VALA_CONSTRUCTOR_THIS_PARAMETER,
-	VALA_CONSTRUCTOR_INSTANCE
+	VALA_CONSTRUCTOR_BINDING
 };
 static void vala_constructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_constructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -113,15 +114,15 @@ void vala_constructor_set_this_parameter (ValaConstructor* self, ValaFormalParam
 }
 
 
-gboolean vala_constructor_get_instance (ValaConstructor* self) {
-	g_return_val_if_fail (VALA_IS_CONSTRUCTOR (self), FALSE);
-	return self->priv->_instance;
+MemberBinding vala_constructor_get_binding (ValaConstructor* self) {
+	g_return_val_if_fail (VALA_IS_CONSTRUCTOR (self), 0);
+	return self->priv->_binding;
 }
 
 
-void vala_constructor_set_instance (ValaConstructor* self, gboolean value) {
+void vala_constructor_set_binding (ValaConstructor* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_CONSTRUCTOR (self));
-	self->priv->_instance = value;
+	self->priv->_binding = value;
 }
 
 
@@ -135,8 +136,8 @@ static void vala_constructor_get_property (GObject * object, guint property_id,
 		case VALA_CONSTRUCTOR_THIS_PARAMETER:
 		g_value_set_object (value, vala_constructor_get_this_parameter (self));
 		break;
-		case VALA_CONSTRUCTOR_INSTANCE:
-		g_value_set_boolean (value, vala_constructor_get_instance (self));
+		case VALA_CONSTRUCTOR_BINDING:
+		g_value_set_enum (value, vala_constructor_get_binding (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -155,8 +156,8 @@ static void vala_constructor_set_property (GObject * object, guint property_id,
 		case VALA_CONSTRUCTOR_THIS_PARAMETER:
 		vala_constructor_set_this_parameter (self, g_value_get_object (value));
 		break;
-		case VALA_CONSTRUCTOR_INSTANCE:
-		vala_constructor_set_instance (self, g_value_get_boolean (value));
+		case VALA_CONSTRUCTOR_BINDING:
+		vala_constructor_set_binding (self, g_value_get_enum (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -175,13 +176,13 @@ static void vala_constructor_class_init (ValaConstructorClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_constructor_real_accept_children;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CONSTRUCTOR_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_constructor_init (ValaConstructor * self) {
 	self->priv = VALA_CONSTRUCTOR_GET_PRIVATE (self);
-	self->priv->_instance = TRUE;
+	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 }
 
 
