@@ -49,6 +49,7 @@ struct _ValaDataTypePrivate {
 	gboolean _is_dynamic;
 	GeeList* type_argument_list;
 };
+
 #define VALA_DATA_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DATA_TYPE, ValaDataTypePrivate))
 enum  {
 	VALA_DATA_TYPE_DUMMY_PROPERTY,
@@ -61,7 +62,7 @@ enum  {
 	VALA_DATA_TYPE_IS_DYNAMIC
 };
 static void vala_data_type_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static char* vala_data_type_real_get_cname (ValaDataType* self, gboolean var_type, gboolean const_type);
+static char* vala_data_type_real_get_cname (ValaDataType* self);
 static char* vala_data_type_real_get_lower_case_cname (ValaDataType* self, const char* infix);
 static char* vala_data_type_real_to_string (ValaCodeNode* base);
 static gboolean vala_data_type_real_equals (ValaDataType* self, ValaDataType* type2);
@@ -78,6 +79,7 @@ static ValaSymbol* vala_data_type_real_get_member (ValaDataType* self, const cha
 static ValaSymbol* vala_data_type_real_get_pointer_member (ValaDataType* self, const char* member_name);
 static gboolean vala_data_type_real_is_real_struct_type (ValaDataType* self);
 static char* vala_data_type_real_get_type_id (ValaDataType* self);
+static char* vala_data_type_real_get_type_signature (ValaDataType* self);
 static gpointer vala_data_type_parent_class = NULL;
 static void vala_data_type_dispose (GObject * obj);
 
@@ -146,58 +148,16 @@ static void vala_data_type_real_accept (ValaCodeNode* base, ValaCodeVisitor* vis
  *
  * @return the type string to be used in C code
  */
-static char* vala_data_type_real_get_cname (ValaDataType* self, gboolean var_type, gboolean const_type) {
-	char* ptr;
+static char* vala_data_type_real_get_cname (ValaDataType* self) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
-	if (self->priv->_data_type == NULL && self->priv->_type_parameter == NULL) {
-		if (var_type) {
-			return g_strdup ("gpointer");
-		} else {
-			return g_strdup ("void");
-		}
-	}
-	ptr = NULL;
-	if (self->priv->_type_parameter != NULL || !vala_typesymbol_is_reference_type (self->priv->_data_type)) {
-		char* _tmp2;
-		_tmp2 = NULL;
-		ptr = (_tmp2 = g_strdup (""), (ptr = (g_free (ptr), NULL)), _tmp2);
-	} else {
-		char* _tmp3;
-		_tmp3 = NULL;
-		ptr = (_tmp3 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), _tmp3);
-	}
-	if (self->priv->_data_type != NULL) {
-		char* _tmp4;
-		char* _tmp5;
-		char* _tmp6;
-		_tmp4 = NULL;
-		_tmp5 = NULL;
-		_tmp6 = NULL;
-		return (_tmp6 = (_tmp5 = g_strconcat ((_tmp4 = vala_typesymbol_get_cname (self->priv->_data_type, const_type)), ptr, NULL), (_tmp4 = (g_free (_tmp4), NULL)), _tmp5), (ptr = (g_free (ptr), NULL)), _tmp6);
-	} else {
-		if (self->priv->_type_parameter != NULL) {
-			if (const_type) {
-				char* _tmp7;
-				_tmp7 = NULL;
-				return (_tmp7 = g_strdup ("gconstpointer"), (ptr = (g_free (ptr), NULL)), _tmp7);
-			} else {
-				char* _tmp8;
-				_tmp8 = NULL;
-				return (_tmp8 = g_strdup ("gpointer"), (ptr = (g_free (ptr), NULL)), _tmp8);
-			}
-		} else {
-			gpointer _tmp9;
-			/* raise error */
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), "unresolved type reference");
-			return (_tmp9 = NULL, (ptr = (g_free (ptr), NULL)), _tmp9);
-		}
-	}
-	ptr = (g_free (ptr), NULL);
+	/* raise error*/
+	vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), "unresolved type reference");
+	return NULL;
 }
 
 
-char* vala_data_type_get_cname (ValaDataType* self, gboolean var_type, gboolean const_type) {
-	return VALA_DATA_TYPE_GET_CLASS (self)->get_cname (self, var_type, const_type);
+char* vala_data_type_get_cname (ValaDataType* self) {
+	return VALA_DATA_TYPE_GET_CLASS (self)->get_cname (self);
 }
 
 
@@ -269,7 +229,7 @@ static char* vala_data_type_real_to_string (ValaCodeNode* base) {
 	ValaDataType * self;
 	char* s;
 	GeeList* type_args;
-	char* _tmp12;
+	char* _tmp11;
 	self = VALA_DATA_TYPE (base);
 	s = NULL;
 	if (self->priv->_data_type != NULL) {
@@ -293,7 +253,7 @@ static char* vala_data_type_real_to_string (ValaCodeNode* base) {
 	if (!(VALA_IS_ARRAY_TYPE (self)) && gee_collection_get_size (GEE_COLLECTION (type_args)) > 0) {
 		char* _tmp4;
 		gboolean first;
-		char* _tmp10;
+		char* _tmp9;
 		_tmp4 = NULL;
 		s = (_tmp4 = g_strconcat (s, ("<"), NULL), (s = (g_free (s), NULL)), _tmp4);
 		first = TRUE;
@@ -306,6 +266,8 @@ static char* vala_data_type_real_to_string (ValaCodeNode* base) {
 				ValaDataType* type_arg;
 				type_arg = ((ValaDataType*) gee_iterator_get (type_arg_it));
 				{
+					char* _tmp8;
+					char* _tmp7;
 					if (!first) {
 						char* _tmp5;
 						_tmp5 = NULL;
@@ -318,33 +280,25 @@ static char* vala_data_type_real_to_string (ValaCodeNode* base) {
 						_tmp6 = NULL;
 						s = (_tmp6 = g_strconcat (s, ("weak "), NULL), (s = (g_free (s), NULL)), _tmp6);
 					}
-					if (type_arg->priv->_data_type != NULL) {
-						char* _tmp8;
-						char* _tmp7;
-						_tmp8 = NULL;
-						_tmp7 = NULL;
-						s = (_tmp8 = g_strconcat (s, (_tmp7 = (vala_symbol_get_full_name (VALA_SYMBOL (type_arg->priv->_data_type)))), NULL), (s = (g_free (s), NULL)), _tmp8);
-						_tmp7 = (g_free (_tmp7), NULL);
-					} else {
-						char* _tmp9;
-						_tmp9 = NULL;
-						s = (_tmp9 = g_strconcat (s, (vala_symbol_get_name (VALA_SYMBOL (type_arg->priv->_type_parameter))), NULL), (s = (g_free (s), NULL)), _tmp9);
-					}
+					_tmp8 = NULL;
+					_tmp7 = NULL;
+					s = (_tmp8 = g_strconcat (s, (_tmp7 = (vala_code_node_to_string (VALA_CODE_NODE (type_arg)))), NULL), (s = (g_free (s), NULL)), _tmp8);
+					_tmp7 = (g_free (_tmp7), NULL);
 					(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
 				}
 			}
 			(type_arg_it == NULL ? NULL : (type_arg_it = (g_object_unref (type_arg_it), NULL)));
 		}
-		_tmp10 = NULL;
-		s = (_tmp10 = g_strconcat (s, (">"), NULL), (s = (g_free (s), NULL)), _tmp10);
+		_tmp9 = NULL;
+		s = (_tmp9 = g_strconcat (s, (">"), NULL), (s = (g_free (s), NULL)), _tmp9);
 	}
 	if (self->priv->_nullable) {
-		char* _tmp11;
-		_tmp11 = NULL;
-		s = (_tmp11 = g_strconcat (s, ("?"), NULL), (s = (g_free (s), NULL)), _tmp11);
+		char* _tmp10;
+		_tmp10 = NULL;
+		s = (_tmp10 = g_strconcat (s, ("?"), NULL), (s = (g_free (s), NULL)), _tmp10);
 	}
-	_tmp12 = NULL;
-	return (_tmp12 = s, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), _tmp12);
+	_tmp11 = NULL;
+	return (_tmp11 = s, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), _tmp11);
 }
 
 
@@ -694,7 +648,7 @@ char* vala_data_type_get_type_id (ValaDataType* self) {
 /**
  * Returns type signature as used for GVariant and D-Bus.
  */
-char* vala_data_type_get_type_signature (ValaDataType* self) {
+static char* vala_data_type_real_get_type_signature (ValaDataType* self) {
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
 	if (self->priv->_data_type != NULL) {
 		return vala_typesymbol_get_type_signature (self->priv->_data_type);
@@ -704,6 +658,11 @@ char* vala_data_type_get_type_signature (ValaDataType* self) {
 }
 
 
+char* vala_data_type_get_type_signature (ValaDataType* self) {
+	return VALA_DATA_TYPE_GET_CLASS (self)->get_type_signature (self);
+}
+
+
 /**
  * A reference to a data type. This is used to specify static types of
  * expressions.
@@ -891,6 +850,7 @@ static void vala_data_type_class_init (ValaDataTypeClass * klass) {
 	VALA_DATA_TYPE_CLASS (klass)->get_pointer_member = vala_data_type_real_get_pointer_member;
 	VALA_DATA_TYPE_CLASS (klass)->is_real_struct_type = vala_data_type_real_is_real_struct_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_data_type_real_get_type_id;
+	VALA_DATA_TYPE_CLASS (klass)->get_type_signature = vala_data_type_real_get_type_signature;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_TRANSFERS_OWNERSHIP, g_param_spec_boolean ("transfers-ownership", "transfers-ownership", "transfers-ownership", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_TAKES_OWNERSHIP, g_param_spec_boolean ("takes-ownership", "takes-ownership", "takes-ownership", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_NULLABLE, g_param_spec_boolean ("nullable", "nullable", "nullable", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
