@@ -53,9 +53,10 @@ struct _ValaDataType {
 	ValaCodeNode parent_instance;
 	ValaDataTypePrivate * priv;
 };
+
 struct _ValaDataTypeClass {
 	ValaCodeNodeClass parent_class;
-	char* (*get_cname) (ValaDataType* self, gboolean var_type, gboolean const_type);
+	char* (*get_cname) (ValaDataType* self);
 	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
 	ValaDataType* (*copy) (ValaDataType* self);
 	gboolean (*equals) (ValaDataType* self, ValaDataType* type2);
@@ -71,12 +72,14 @@ struct _ValaDataTypeClass {
 	ValaSymbol* (*get_pointer_member) (ValaDataType* self, const char* member_name);
 	gboolean (*is_real_struct_type) (ValaDataType* self);
 	char* (*get_type_id) (ValaDataType* self);
+	char* (*get_type_signature) (ValaDataType* self);
 };
 
+
 void vala_data_type_add_type_argument (ValaDataType* self, ValaDataType* arg);
 GeeList* vala_data_type_get_type_arguments (ValaDataType* self);
 void vala_data_type_remove_all_type_arguments (ValaDataType* self);
-char* vala_data_type_get_cname (ValaDataType* self, gboolean var_type, gboolean const_type);
+char* vala_data_type_get_cname (ValaDataType* self);
 char* vala_data_type_get_const_cname (ValaDataType* self);
 char* vala_data_type_get_lower_case_cname (ValaDataType* self, const char* infix);
 ValaDataType* vala_data_type_copy (ValaDataType* self);
