@@ -52,10 +52,12 @@ struct _ValaDelegate {
 	ValaTypesymbol parent_instance;
 	ValaDelegatePrivate * priv;
 };
+
 struct _ValaDelegateClass {
 	ValaTypesymbolClass parent_class;
 };
 
+
 ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 void vala_delegate_add_type_parameter (ValaDelegate* self, ValaTypeParameter* p);
 void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param);
@@ -65,8 +67,8 @@ void vala_delegate_set_cname (ValaDelegate* self, const char* cname);
 void vala_delegate_process_attributes (ValaDelegate* self);
 ValaDataType* vala_delegate_get_return_type (ValaDelegate* self);
 void vala_delegate_set_return_type (ValaDelegate* self, ValaDataType* value);
-gboolean vala_delegate_get_instance (ValaDelegate* self);
-void vala_delegate_set_instance (ValaDelegate* self, gboolean value);
+gboolean vala_delegate_get_has_target (ValaDelegate* self);
+void vala_delegate_set_has_target (ValaDelegate* self, gboolean value);
 double vala_delegate_get_cinstance_parameter_position (ValaDelegate* self);
 void vala_delegate_set_cinstance_parameter_position (ValaDelegate* self, double value);
 double vala_delegate_get_carray_length_parameter_position (ValaDelegate* self);
