@@ -32,14 +32,15 @@
 struct _ValaDestructorPrivate {
 	ValaBlock* _body;
 	ValaFormalParameter* _this_parameter;
-	gboolean _instance;
+	MemberBinding _binding;
 };
+
 #define VALA_DESTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DESTRUCTOR, ValaDestructorPrivate))
 enum  {
 	VALA_DESTRUCTOR_DUMMY_PROPERTY,
 	VALA_DESTRUCTOR_BODY,
 	VALA_DESTRUCTOR_THIS_PARAMETER,
-	VALA_DESTRUCTOR_INSTANCE
+	VALA_DESTRUCTOR_BINDING
 };
 static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -113,15 +114,15 @@ void vala_destructor_set_this_parameter (ValaDestructor* self, ValaFormalParamet
 }
 
 
-gboolean vala_destructor_get_instance (ValaDestructor* self) {
-	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), FALSE);
-	return self->priv->_instance;
+MemberBinding vala_destructor_get_binding (ValaDestructor* self) {
+	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), 0);
+	return self->priv->_binding;
 }
 
 
-void vala_destructor_set_instance (ValaDestructor* self, gboolean value) {
+void vala_destructor_set_binding (ValaDestructor* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
-	self->priv->_instance = value;
+	self->priv->_binding = value;
 }
 
 
@@ -135,8 +136,8 @@ static void vala_destructor_get_property (GObject * object, guint property_id, G
 		case VALA_DESTRUCTOR_THIS_PARAMETER:
 		g_value_set_object (value, vala_destructor_get_this_parameter (self));
 		break;
-		case VALA_DESTRUCTOR_INSTANCE:
-		g_value_set_boolean (value, vala_destructor_get_instance (self));
+		case VALA_DESTRUCTOR_BINDING:
+		g_value_set_enum (value, vala_destructor_get_binding (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -155,8 +156,8 @@ static void vala_destructor_set_property (GObject * object, guint property_id, c
 		case VALA_DESTRUCTOR_THIS_PARAMETER:
 		vala_destructor_set_this_parameter (self, g_value_get_object (value));
 		break;
-		case VALA_DESTRUCTOR_INSTANCE:
-		vala_destructor_set_instance (self, g_value_get_boolean (value));
+		case VALA_DESTRUCTOR_BINDING:
+		vala_destructor_set_binding (self, g_value_get_enum (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -175,13 +176,13 @@ static void vala_destructor_class_init (ValaDestructorClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_destructor_real_accept_children;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", TRUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_destructor_init (ValaDestructor * self) {
 	self->priv = VALA_DESTRUCTOR_GET_PRIVATE (self);
-	self->priv->_instance = TRUE;
+	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 }
 
 
