@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 enum  {
 	VALA_EMPTY_STATEMENT_DUMMY_PROPERTY
 };
@@ -32,6 +35,7 @@ static gpointer vala_empty_statement_parent_class = NULL;
 static ValaStatementIface* vala_empty_statement_vala_statement_parent_iface = NULL;
 
 
+
 /**
  * Creates a new empty statement.
  *
@@ -40,7 +44,7 @@ static ValaStatementIface* vala_empty_statement_vala_statement_parent_iface = NU
  */
 ValaEmptyStatement* vala_empty_statement_new (ValaSourceReference* source) {
 	ValaEmptyStatement * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_EMPTY_STATEMENT, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
