@@ -24,6 +24,7 @@
 #include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valaattribute.h>
 #include <vala/valaenum.h>
 
 
@@ -33,6 +34,7 @@ struct _ValaEnumValuePrivate {
 	ValaExpression* _value;
 	char* cname;
 };
+
 #define VALA_ENUM_VALUE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ENUM_VALUE, ValaEnumValuePrivate))
 enum  {
 	VALA_ENUM_VALUE_DUMMY_PROPERTY,
@@ -42,6 +44,7 @@ static void vala_enum_value_real_accept (ValaCodeNode* base, ValaCodeVisitor* vi
 static void vala_enum_value_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gpointer vala_enum_value_parent_class = NULL;
 static void vala_enum_value_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
@@ -135,6 +138,33 @@ static void vala_enum_value_real_accept_children (ValaCodeNode* base, ValaCodeVi
 }
 
 
+/**
+ * Process all associated attributes.
+ */
+void vala_enum_value_process_attributes (ValaEnumValue* self) {
+	g_return_if_fail (VALA_IS_ENUM_VALUE (self));
+	{
+		GList* a_collection;
+		GList* a_it;
+		a_collection = VALA_CODE_NODE (self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* _tmp1;
+			ValaAttribute* a;
+			_tmp1 = NULL;
+			a = (_tmp1 = ((ValaAttribute*) a_it->data), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			{
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0 && vala_attribute_has_argument (a, "cname")) {
+					char* _tmp0;
+					_tmp0 = NULL;
+					self->priv->cname = (_tmp0 = vala_attribute_get_string (a, "cname"), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
+				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
+			}
+		}
+	}
+}
+
+
 /**
  * Returns the name of this enum value as it is used in C code.
  *
@@ -241,5 +271,16 @@ GType vala_enum_value_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
