@@ -31,6 +31,7 @@
 #include <vala/valascope.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valareport.h>
+#include <vala/valamember.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valavaluetype.h>
 #include <vala/valadatatype.h>
@@ -48,6 +49,7 @@ struct _ValaErrorDomainPrivate {
 	char* lower_case_cprefix;
 	char* lower_case_csuffix;
 };
+
 #define VALA_ERROR_DOMAIN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ERROR_DOMAIN, ValaErrorDomainPrivate))
 enum  {
 	VALA_ERROR_DOMAIN_DUMMY_PROPERTY
@@ -117,7 +119,7 @@ void vala_error_domain_add_method (ValaErrorDomain* self, ValaMethod* m) {
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
 		return;
 	}
-	if (vala_method_get_instance (m)) {
+	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		ValaFormalParameter* _tmp1;
 		ValaValueType* _tmp0;
 		_tmp1 = NULL;
