@@ -33,19 +33,20 @@
 
 struct _ValaFieldPrivate {
 	ValaExpression* _initializer;
+	MemberBinding _binding;
 	gboolean _is_volatile;
 	gboolean _no_array_length;
 	char* cname;
-	gboolean _instance;
 	gboolean lock_used;
 	ValaDataType* _data_type;
 };
+
 #define VALA_FIELD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FIELD, ValaFieldPrivate))
 enum  {
 	VALA_FIELD_DUMMY_PROPERTY,
 	VALA_FIELD_TYPE_REFERENCE,
 	VALA_FIELD_INITIALIZER,
-	VALA_FIELD_INSTANCE,
+	VALA_FIELD_BINDING,
 	VALA_FIELD_IS_VOLATILE,
 	VALA_FIELD_NO_ARRAY_LENGTH
 };
@@ -148,7 +149,7 @@ void vala_field_set_cname (ValaField* self, const char* cname) {
  */
 char* vala_field_get_default_cname (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
-	if (!vala_field_get_instance (self)) {
+	if (self->priv->_binding == MEMBER_BINDING_STATIC) {
 		char* _tmp0;
 		char* _tmp1;
 		_tmp0 = NULL;
@@ -284,15 +285,15 @@ void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
 }
 
 
-gboolean vala_field_get_instance (ValaField* self) {
-	g_return_val_if_fail (VALA_IS_FIELD (self), FALSE);
-	return self->priv->_instance;
+MemberBinding vala_field_get_binding (ValaField* self) {
+	g_return_val_if_fail (VALA_IS_FIELD (self), 0);
+	return self->priv->_binding;
 }
 
 
-void vala_field_set_instance (ValaField* self, gboolean value) {
+void vala_field_set_binding (ValaField* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
-	self->priv->_instance = value;
+	self->priv->_binding = value;
 }
 
 
@@ -330,8 +331,8 @@ static void vala_field_get_property (GObject * object, guint property_id, GValue
 		case VALA_FIELD_INITIALIZER:
 		g_value_set_object (value, vala_field_get_initializer (self));
 		break;
-		case VALA_FIELD_INSTANCE:
-		g_value_set_boolean (value, vala_field_get_instance (self));
+		case VALA_FIELD_BINDING:
+		g_value_set_enum (value, vala_field_get_binding (self));
 		break;
 		case VALA_FIELD_IS_VOLATILE:
 		g_value_set_boolean (value, vala_field_get_is_volatile (self));
@@ -356,8 +357,8 @@ static void vala_field_set_property (GObject * object, guint property_id, const
 		case VALA_FIELD_INITIALIZER:
 		vala_field_set_initializer (self, g_value_get_object (value));
 		break;
-		case VALA_FIELD_INSTANCE:
-		vala_field_set_instance (self, g_value_get_boolean (value));
+		case VALA_FIELD_BINDING:
+		vala_field_set_binding (self, g_value_get_enum (value));
 		break;
 		case VALA_FIELD_IS_VOLATILE:
 		vala_field_set_is_volatile (self, g_value_get_boolean (value));
@@ -383,7 +384,7 @@ static void vala_field_class_init (ValaFieldClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_field_real_replace_type;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INITIALIZER, g_param_spec_object ("initializer", "initializer", "initializer", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_IS_VOLATILE, g_param_spec_boolean ("is-volatile", "is-volatile", "is-volatile", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -398,7 +399,7 @@ static void vala_field_vala_lockable_interface_init (ValaLockableIface * iface)
 
 static void vala_field_init (ValaField * self) {
 	self->priv = VALA_FIELD_GET_PRIVATE (self);
-	self->priv->_instance = TRUE;
+	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 	self->priv->lock_used = FALSE;
 }
 
