@@ -50,10 +50,12 @@ struct _ValaField {
 	ValaMember parent_instance;
 	ValaFieldPrivate * priv;
 };
+
 struct _ValaFieldClass {
 	ValaMemberClass parent_class;
 };
 
+
 ValaField* vala_field_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference);
 char* vala_field_get_cname (ValaField* self);
 void vala_field_set_cname (ValaField* self, const char* cname);
@@ -63,8 +65,8 @@ ValaDataType* vala_field_get_type_reference (ValaField* self);
 void vala_field_set_type_reference (ValaField* self, ValaDataType* value);
 ValaExpression* vala_field_get_initializer (ValaField* self);
 void vala_field_set_initializer (ValaField* self, ValaExpression* value);
-gboolean vala_field_get_instance (ValaField* self);
-void vala_field_set_instance (ValaField* self, gboolean value);
+MemberBinding vala_field_get_binding (ValaField* self);
+void vala_field_set_binding (ValaField* self, MemberBinding value);
 gboolean vala_field_get_is_volatile (ValaField* self);
 void vala_field_set_is_volatile (ValaField* self, gboolean value);
 gboolean vala_field_get_no_array_length (ValaField* self);
