@@ -28,7 +28,11 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaFormalParameterPrivate {
+	ValaParameterDirection _direction;
 	gboolean _ellipsis;
 	ValaExpression* _default_expression;
 	gboolean _no_array_length;
@@ -38,10 +42,12 @@ struct _ValaFormalParameterPrivate {
 	double _cdelegate_target_parameter_position;
 	ValaDataType* _data_type;
 };
+
 #define VALA_FORMAL_PARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FORMAL_PARAMETER, ValaFormalParameterPrivate))
 enum  {
 	VALA_FORMAL_PARAMETER_DUMMY_PROPERTY,
 	VALA_FORMAL_PARAMETER_TYPE_REFERENCE,
+	VALA_FORMAL_PARAMETER_DIRECTION,
 	VALA_FORMAL_PARAMETER_ELLIPSIS,
 	VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION,
 	VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH,
@@ -60,6 +66,7 @@ static void vala_formal_parameter_dispose (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new formal parameter.
  *
@@ -70,7 +77,8 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaDataType* type, ValaSourceReference* source) {
 	ValaFormalParameter * self;
-	g_return_val_if_fail (type == NULL || VALA_IS_DATA_TYPE (type), NULL);
+	g_return_val_if_fail (_name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), _name);
@@ -97,7 +105,7 @@ ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReferenc
 static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_formal_parameter (visitor, self);
 }
 
@@ -105,11 +113,11 @@ static void vala_formal_parameter_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	if (!vala_formal_parameter_get_ellipsis (self)) {
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	if (!self->priv->_ellipsis) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_type_reference (self)), visitor);
-		if (vala_formal_parameter_get_default_expression (self) != NULL) {
-			vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_default_expression (self)), visitor);
+		if (self->priv->_default_expression != NULL) {
+			vala_code_node_accept (VALA_CODE_NODE (self->priv->_default_expression), visitor);
 		}
 	}
 }
@@ -118,8 +126,8 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_formal_parameter_get_type_reference (self) == old_type) {
 		vala_formal_parameter_set_type_reference (self, new_type);
 	}
@@ -128,7 +136,7 @@ static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDat
 
 static void vala_formal_parameter_process_ccode_attribute (ValaFormalParameter* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "array_length_pos")) {
 		vala_formal_parameter_set_carray_length_parameter_position (self, vala_attribute_get_double (a, "array_length_pos"));
 	}
@@ -165,7 +173,7 @@ void vala_formal_parameter_process_attributes (ValaFormalParameter* self) {
 
 ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
-	if (!vala_formal_parameter_get_ellipsis (self)) {
+	if (!self->priv->_ellipsis) {
 		ValaFormalParameter* result;
 		result = vala_formal_parameter_new (vala_symbol_get_name (VALA_SYMBOL (self)), vala_formal_parameter_get_type_reference (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 		return result;
@@ -192,6 +200,18 @@ void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaDa
 }
 
 
+ValaParameterDirection vala_formal_parameter_get_direction (ValaFormalParameter* self) {
+	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), 0);
+	return self->priv->_direction;
+}
+
+
+void vala_formal_parameter_set_direction (ValaFormalParameter* self, ValaParameterDirection value) {
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
+	self->priv->_direction = value;
+}
+
+
 gboolean vala_formal_parameter_get_ellipsis (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), FALSE);
 	return self->priv->_ellipsis;
@@ -303,6 +323,9 @@ static void vala_formal_parameter_get_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
 		g_value_set_object (value, vala_formal_parameter_get_type_reference (self));
 		break;
+		case VALA_FORMAL_PARAMETER_DIRECTION:
+		g_value_set_enum (value, vala_formal_parameter_get_direction (self));
+		break;
 		case VALA_FORMAL_PARAMETER_ELLIPSIS:
 		g_value_set_boolean (value, vala_formal_parameter_get_ellipsis (self));
 		break;
@@ -338,6 +361,9 @@ static void vala_formal_parameter_set_property (GObject * object, guint property
 		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
 		vala_formal_parameter_set_type_reference (self, g_value_get_object (value));
 		break;
+		case VALA_FORMAL_PARAMETER_DIRECTION:
+		vala_formal_parameter_set_direction (self, g_value_get_enum (value));
+		break;
 		case VALA_FORMAL_PARAMETER_ELLIPSIS:
 		vala_formal_parameter_set_ellipsis (self, g_value_get_boolean (value));
 		break;
@@ -377,6 +403,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_formal_parameter_real_replace_type;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DIRECTION, g_param_spec_enum ("direction", "direction", "direction", VALA_TYPE_PARAMETER_DIRECTION, VALA_PARAMETER_DIRECTION_IN, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_ELLIPSIS, g_param_spec_boolean ("ellipsis", "ellipsis", "ellipsis", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -389,6 +416,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 
 static void vala_formal_parameter_init (ValaFormalParameter * self) {
 	self->priv = VALA_FORMAL_PARAMETER_GET_PRIVATE (self);
+	self->priv->_direction = VALA_PARAMETER_DIRECTION_IN;
 }
 
 
@@ -411,6 +439,17 @@ GType vala_formal_parameter_get_type (void) {
 }
 
 
+
+GType vala_parameter_direction_get_type (void) {
+	static GType vala_parameter_direction_type_id = 0;
+	if (G_UNLIKELY (vala_parameter_direction_type_id == 0)) {
+		static const GEnumValue values[] = {{VALA_PARAMETER_DIRECTION_IN, "VALA_PARAMETER_DIRECTION_IN", "in"}, {VALA_PARAMETER_DIRECTION_OUT, "VALA_PARAMETER_DIRECTION_OUT", "out"}, {VALA_PARAMETER_DIRECTION_REF, "VALA_PARAMETER_DIRECTION_REF", "ref"}, {0, NULL, NULL}};
+		vala_parameter_direction_type_id = g_enum_register_static ("ValaParameterDirection", values);
+	}
+	return vala_parameter_direction_type_id;
+}
+
+
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
