@@ -39,8 +39,9 @@
 #include <vala/valascope.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valareport.h>
+#include <vala/valamember.h>
 #include <vala/valaformalparameter.h>
-#include <vala/valainterfacetype.h>
+#include <vala/valainterfaceinstancetype.h>
 #include <vala/valavoidtype.h>
 #include <vala/valalocalvariable.h>
 #include <vala/valaexpression.h>
@@ -68,6 +69,7 @@ struct _ValaInterfacePrivate {
 	char* type_cname;
 	char* type_id;
 };
+
 #define VALA_INTERFACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE, ValaInterfacePrivate))
 enum  {
 	VALA_INTERFACE_DUMMY_PROPERTY,
@@ -195,12 +197,12 @@ void vala_interface_add_method (ValaInterface* self, ValaMethod* m) {
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
 		return;
 	}
-	if (vala_method_get_instance (m)) {
+	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		ValaFormalParameter* _tmp1;
-		ValaInterfaceType* _tmp0;
+		ValaInterfaceInstanceType* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_interface_type_new (self))), NULL)));
+		vala_method_set_this_parameter (m, (_tmp1 = vala_formal_parameter_new ("this", VALA_DATA_TYPE ((_tmp0 = vala_interface_instance_type_new (self))), NULL)));
 		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (m)), vala_symbol_get_name (VALA_SYMBOL (vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
