@@ -29,12 +29,16 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaLambdaExpressionPrivate {
 	ValaExpression* _expression_body;
 	ValaBlock* _statement_body;
 	ValaMethod* _method;
 	GeeList* parameters;
 };
+
 #define VALA_LAMBDA_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpressionPrivate))
 enum  {
 	VALA_LAMBDA_EXPRESSION_DUMMY_PROPERTY,
@@ -49,6 +53,7 @@ static gpointer vala_lambda_expression_parent_class = NULL;
 static void vala_lambda_expression_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new lambda expression.
  *
@@ -58,11 +63,11 @@ static void vala_lambda_expression_dispose (GObject * obj);
  */
 ValaLambdaExpression* vala_lambda_expression_new (ValaExpression* expression_body, ValaSourceReference* source_reference) {
 	ValaLambdaExpression * self;
-	g_return_val_if_fail (expression_body == NULL || VALA_IS_EXPRESSION (expression_body), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (expression_body), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_LAMBDA_EXPRESSION, 0, NULL);
-	vala_lambda_expression_set_expression_body (self, expression_body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_lambda_expression_set_expression_body (self, expression_body);
 	return self;
 }
 
@@ -76,8 +81,8 @@ ValaLambdaExpression* vala_lambda_expression_new (ValaExpression* expression_bod
  */
 ValaLambdaExpression* vala_lambda_expression_new_with_statement_body (ValaBlock* statement_body, ValaSourceReference* source_reference) {
 	ValaLambdaExpression * self;
-	g_return_val_if_fail (statement_body == NULL || VALA_IS_BLOCK (statement_body), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (statement_body), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_LAMBDA_EXPRESSION, 0, NULL);
 	vala_lambda_expression_set_statement_body (self, statement_body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -92,6 +97,7 @@ ValaLambdaExpression* vala_lambda_expression_new_with_statement_body (ValaBlock*
  */
 void vala_lambda_expression_add_parameter (ValaLambdaExpression* self, const char* param) {
 	g_return_if_fail (VALA_IS_LAMBDA_EXPRESSION (self));
+	g_return_if_fail (param != NULL);
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
 }
 
@@ -110,7 +116,7 @@ GeeCollection* vala_lambda_expression_get_parameters (ValaLambdaExpression* self
 static void vala_lambda_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaLambdaExpression * self;
 	self = VALA_LAMBDA_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_lambda_expression (visitor, self);
 }
 
@@ -118,18 +124,18 @@ static void vala_lambda_expression_real_accept (ValaCodeNode* base, ValaCodeVisi
 static void vala_lambda_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaLambdaExpression * self;
 	self = VALA_LAMBDA_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	if (vala_lambda_expression_get_method (self) == NULL) {
-		if (vala_lambda_expression_get_expression_body (self) != NULL) {
-			vala_code_node_accept (VALA_CODE_NODE (vala_lambda_expression_get_expression_body (self)), visitor);
-			vala_code_visitor_visit_end_full_expression (visitor, vala_lambda_expression_get_expression_body (self));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	if (self->priv->_method == NULL) {
+		if (self->priv->_expression_body != NULL) {
+			vala_code_node_accept (VALA_CODE_NODE (self->priv->_expression_body), visitor);
+			vala_code_visitor_visit_end_full_expression (visitor, self->priv->_expression_body);
 		} else {
-			if (vala_lambda_expression_get_statement_body (self) != NULL) {
-				vala_code_node_accept (VALA_CODE_NODE (vala_lambda_expression_get_statement_body (self)), visitor);
+			if (self->priv->_statement_body != NULL) {
+				vala_code_node_accept (VALA_CODE_NODE (self->priv->_statement_body), visitor);
 			}
 		}
 	} else {
-		vala_code_node_accept (VALA_CODE_NODE (vala_lambda_expression_get_method (self)), visitor);
+		vala_code_node_accept (VALA_CODE_NODE (self->priv->_method), visitor);
 	}
 }
 
