@@ -48,13 +48,15 @@ typedef struct _ValaLambdaExpressionPrivate ValaLambdaExpressionPrivate;
  * anonymous methods with implicitly typed parameters.
  */
 struct _ValaLambdaExpression {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaLambdaExpressionPrivate * priv;
 };
+
 struct _ValaLambdaExpressionClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
+
 ValaLambdaExpression* vala_lambda_expression_new (ValaExpression* expression_body, ValaSourceReference* source_reference);
 ValaLambdaExpression* vala_lambda_expression_new_with_statement_body (ValaBlock* statement_body, ValaSourceReference* source_reference);
 void vala_lambda_expression_add_parameter (ValaLambdaExpression* self, const char* param);
@@ -67,6 +69,7 @@ ValaMethod* vala_lambda_expression_get_method (ValaLambdaExpression* self);
 void vala_lambda_expression_set_method (ValaLambdaExpression* self, ValaMethod* value);
 GType vala_lambda_expression_get_type (void);
 
+
 G_END_DECLS
 
 #endif
