@@ -1,11 +1,11 @@
 /* valamember.vala
  *
- * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,11 +17,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
-#ifndef __VALAMEMBER_H__
-#define __VALAMEMBER_H__
+#ifndef __VALA_VALAMEMBER_H__
+#define __VALA_VALAMEMBER_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -43,19 +43,32 @@ G_BEGIN_DECLS
 
 typedef struct _ValaMemberPrivate ValaMemberPrivate;
 
+#define TYPE_MEMBER_BINDING (member_binding_get_type ())
+
 /**
  * Represents a general class member.
  */
 struct _ValaMember {
-	ValaSymbol parent;
+	ValaSymbol parent_instance;
 	ValaMemberPrivate * priv;
 };
+
 struct _ValaMemberClass {
-	ValaSymbolClass parent;
+	ValaSymbolClass parent_class;
 };
 
+typedef enum  {
+	MEMBER_BINDING_INSTANCE,
+	MEMBER_BINDING_CLASS,
+	MEMBER_BINDING_STATIC
+} MemberBinding;
+
+
 void vala_member_add_cheader_filename (ValaMember* self, const char* filename);
+ValaMember* vala_member_new (void);
 GType vala_member_get_type (void);
+GType member_binding_get_type (void);
+
 
 G_END_DECLS
 
