@@ -46,6 +46,7 @@
 struct _ValaMethodPrivate {
 	ValaBasicBlock* _entry_block;
 	ValaBasicBlock* _exit_block;
+	MemberBinding _binding;
 	gboolean _is_abstract;
 	gboolean _is_virtual;
 	gboolean _overrides;
@@ -59,7 +60,6 @@ struct _ValaMethodPrivate {
 	double _carray_length_parameter_position;
 	double _cdelegate_target_parameter_position;
 	gboolean _printf_format;
-	gboolean _instance;
 	GeeList* parameters;
 	char* cname;
 	char* _vfunc_name;
@@ -71,6 +71,7 @@ struct _ValaMethodPrivate {
 	ValaDataType* _return_type;
 	ValaBlock* _body;
 };
+
 #define VALA_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_METHOD, ValaMethodPrivate))
 enum  {
 	VALA_METHOD_DUMMY_PROPERTY,
@@ -78,7 +79,7 @@ enum  {
 	VALA_METHOD_BODY,
 	VALA_METHOD_ENTRY_BLOCK,
 	VALA_METHOD_EXIT_BLOCK,
-	VALA_METHOD_INSTANCE,
+	VALA_METHOD_BINDING,
 	VALA_METHOD_VFUNC_NAME,
 	VALA_METHOD_SENTINEL,
 	VALA_METHOD_IS_ABSTRACT,
@@ -462,7 +463,7 @@ void vala_method_process_attributes (ValaMethod* self) {
  * @param invalid_match error string about which check failed
  * @return true if the specified method is compatible to this method
  */
-gboolean vala_method_compatible (ValaMethod* self, ValaMethod* base_method, const char** invalid_match) {
+gboolean vala_method_compatible (ValaMethod* self, ValaMethod* base_method, char** invalid_match) {
 	GeeIterator* method_params_it;
 	gint param_index;
 	gboolean _tmp13;
@@ -741,15 +742,15 @@ void vala_method_set_exit_block (ValaMethod* self, ValaBasicBlock* value) {
 }
 
 
-gboolean vala_method_get_instance (ValaMethod* self) {
-	g_return_val_if_fail (VALA_IS_METHOD (self), FALSE);
-	return self->priv->_instance;
+MemberBinding vala_method_get_binding (ValaMethod* self) {
+	g_return_val_if_fail (VALA_IS_METHOD (self), 0);
+	return self->priv->_binding;
 }
 
 
-void vala_method_set_instance (ValaMethod* self, gboolean value) {
+void vala_method_set_binding (ValaMethod* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_METHOD (self));
-	self->priv->_instance = value;
+	self->priv->_binding = value;
 }
 
 
@@ -1023,8 +1024,8 @@ static void vala_method_get_property (GObject * object, guint property_id, GValu
 		case VALA_METHOD_EXIT_BLOCK:
 		g_value_set_object (value, vala_method_get_exit_block (self));
 		break;
-		case VALA_METHOD_INSTANCE:
-		g_value_set_boolean (value, vala_method_get_instance (self));
+		case VALA_METHOD_BINDING:
+		g_value_set_enum (value, vala_method_get_binding (self));
 		break;
 		case VALA_METHOD_VFUNC_NAME:
 		g_value_set_string (value, vala_method_get_vfunc_name (self));
@@ -1097,8 +1098,8 @@ static void vala_method_set_property (GObject * object, guint property_id, const
 		case VALA_METHOD_EXIT_BLOCK:
 		vala_method_set_exit_block (self, g_value_get_object (value));
 		break;
-		case VALA_METHOD_INSTANCE:
-		vala_method_set_instance (self, g_value_get_boolean (value));
+		case VALA_METHOD_BINDING:
+		vala_method_set_binding (self, g_value_get_enum (value));
 		break;
 		case VALA_METHOD_VFUNC_NAME:
 		vala_method_set_vfunc_name (self, g_value_get_string (value));
@@ -1171,7 +1172,7 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_ENTRY_BLOCK, g_param_spec_object ("entry-block", "entry-block", "entry-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_EXIT_BLOCK, g_param_spec_object ("exit-block", "exit-block", "exit-block", VALA_TYPE_BASIC_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_VFUNC_NAME, g_param_spec_string ("vfunc-name", "vfunc-name", "vfunc-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_SENTINEL, g_param_spec_string ("sentinel", "sentinel", "sentinel", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_METHOD_IS_ABSTRACT, g_param_spec_boolean ("is-abstract", "is-abstract", "is-abstract", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -1193,7 +1194,7 @@ static void vala_method_class_init (ValaMethodClass * klass) {
 
 static void vala_method_init (ValaMethod * self) {
 	self->priv = VALA_METHOD_GET_PRIVATE (self);
-	self->priv->_instance = TRUE;
+	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->error_domains = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 	self->priv->preconditions = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
