@@ -54,11 +54,13 @@ struct _ValaMethod {
 	ValaMember parent_instance;
 	ValaMethodPrivate * priv;
 };
+
 struct _ValaMethodClass {
 	ValaMemberClass parent_class;
 	char* (*get_default_cname) (ValaMethod* self);
 };
 
+
 #define VALA_METHOD_DEFAULT_SENTINEL "NULL"
 ValaMethod* vala_method_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 void vala_method_add_parameter (ValaMethod* self, ValaFormalParameter* param);
@@ -69,7 +71,7 @@ char* vala_method_get_default_cname (ValaMethod* self);
 char* vala_method_get_real_cname (ValaMethod* self);
 void vala_method_set_cname (ValaMethod* self, const char* cname);
 void vala_method_process_attributes (ValaMethod* self);
-gboolean vala_method_compatible (ValaMethod* self, ValaMethod* base_method, const char** invalid_match);
+gboolean vala_method_compatible (ValaMethod* self, ValaMethod* base_method, char** invalid_match);
 void vala_method_add_error_domain (ValaMethod* self, ValaDataType* error_domain);
 GeeCollection* vala_method_get_error_domains (ValaMethod* self);
 void vala_method_add_precondition (ValaMethod* self, ValaExpression* precondition);
@@ -84,8 +86,8 @@ ValaBasicBlock* vala_method_get_entry_block (ValaMethod* self);
 void vala_method_set_entry_block (ValaMethod* self, ValaBasicBlock* value);
 ValaBasicBlock* vala_method_get_exit_block (ValaMethod* self);
 void vala_method_set_exit_block (ValaMethod* self, ValaBasicBlock* value);
-gboolean vala_method_get_instance (ValaMethod* self);
-void vala_method_set_instance (ValaMethod* self, gboolean value);
+MemberBinding vala_method_get_binding (ValaMethod* self);
+void vala_method_set_binding (ValaMethod* self, MemberBinding value);
 char* vala_method_get_vfunc_name (ValaMethod* self);
 void vala_method_set_vfunc_name (ValaMethod* self, const char* value);
 char* vala_method_get_sentinel (ValaMethod* self);
