@@ -34,8 +34,11 @@
 #include <vala/valamethod.h>
 #include <vala/valasourcereference.h>
 #include <vala/valascope.h>
+#include <vala/valadatatype.h>
+#include <vala/valasourcefile.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valareport.h>
+#include <vala/valamember.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
@@ -57,6 +60,7 @@ struct _ValaNamespacePrivate {
 	GeeList* cheader_filenames;
 	GeeList* namespaces;
 };
+
 #define VALA_NAMESPACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_NAMESPACE, ValaNamespacePrivate))
 enum  {
 	VALA_NAMESPACE_DUMMY_PROPERTY
@@ -100,8 +104,178 @@ ValaNamespace* vala_namespace_new (const char* name, ValaSourceReference* source
 void vala_namespace_add_namespace (ValaNamespace* self, ValaNamespace* ns) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_NAMESPACE (ns));
-	gee_collection_add (GEE_COLLECTION (self->priv->namespaces), ns);
-	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (ns)), VALA_SYMBOL (ns));
+	if (VALA_IS_NAMESPACE (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (ns))))) {
+		ValaNamespace* old_ns;
+		/* merge if namespace already exists*/
+		old_ns = VALA_NAMESPACE (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (ns))));
+		if (vala_symbol_get_external_package (VALA_SYMBOL (old_ns)) && !vala_symbol_get_external_package (VALA_SYMBOL (ns))) {
+			vala_code_node_set_source_reference (VALA_CODE_NODE (old_ns), vala_code_node_get_source_reference (VALA_CODE_NODE (ns)));
+		}
+		{
+			GeeCollection* sub_ns_collection;
+			GeeIterator* sub_ns_it;
+			sub_ns_collection = vala_namespace_get_namespaces (ns);
+			sub_ns_it = gee_iterable_iterator (GEE_ITERABLE (sub_ns_collection));
+			while (gee_iterator_next (sub_ns_it)) {
+				ValaNamespace* sub_ns;
+				sub_ns = ((ValaNamespace*) gee_iterator_get (sub_ns_it));
+				{
+					vala_namespace_add_namespace (old_ns, sub_ns);
+					(sub_ns == NULL ? NULL : (sub_ns = (g_object_unref (sub_ns), NULL)));
+				}
+			}
+			(sub_ns_collection == NULL ? NULL : (sub_ns_collection = (g_object_unref (sub_ns_collection), NULL)));
+			(sub_ns_it == NULL ? NULL : (sub_ns_it = (g_object_unref (sub_ns_it), NULL)));
+		}
+		{
+			GeeCollection* cl_collection;
+			GeeIterator* cl_it;
+			cl_collection = vala_namespace_get_classes (ns);
+			cl_it = gee_iterable_iterator (GEE_ITERABLE (cl_collection));
+			while (gee_iterator_next (cl_it)) {
+				ValaClass* cl;
+				cl = ((ValaClass*) gee_iterator_get (cl_it));
+				{
+					vala_namespace_add_class (old_ns, cl);
+					(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
+				}
+			}
+			(cl_collection == NULL ? NULL : (cl_collection = (g_object_unref (cl_collection), NULL)));
+			(cl_it == NULL ? NULL : (cl_it = (g_object_unref (cl_it), NULL)));
+		}
+		{
+			GeeCollection* st_collection;
+			GeeIterator* st_it;
+			st_collection = vala_namespace_get_structs (ns);
+			st_it = gee_iterable_iterator (GEE_ITERABLE (st_collection));
+			while (gee_iterator_next (st_it)) {
+				ValaStruct* st;
+				st = ((ValaStruct*) gee_iterator_get (st_it));
+				{
+					vala_namespace_add_struct (old_ns, st);
+					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				}
+			}
+			(st_collection == NULL ? NULL : (st_collection = (g_object_unref (st_collection), NULL)));
+			(st_it == NULL ? NULL : (st_it = (g_object_unref (st_it), NULL)));
+		}
+		{
+			GeeCollection* iface_collection;
+			GeeIterator* iface_it;
+			iface_collection = vala_namespace_get_interfaces (ns);
+			iface_it = gee_iterable_iterator (GEE_ITERABLE (iface_collection));
+			while (gee_iterator_next (iface_it)) {
+				ValaInterface* iface;
+				iface = ((ValaInterface*) gee_iterator_get (iface_it));
+				{
+					vala_namespace_add_interface (old_ns, iface);
+					(iface == NULL ? NULL : (iface = (g_object_unref (iface), NULL)));
+				}
+			}
+			(iface_collection == NULL ? NULL : (iface_collection = (g_object_unref (iface_collection), NULL)));
+			(iface_it == NULL ? NULL : (iface_it = (g_object_unref (iface_it), NULL)));
+		}
+		{
+			GeeCollection* d_collection;
+			GeeIterator* d_it;
+			d_collection = vala_namespace_get_delegates (ns);
+			d_it = gee_iterable_iterator (GEE_ITERABLE (d_collection));
+			while (gee_iterator_next (d_it)) {
+				ValaDelegate* d;
+				d = ((ValaDelegate*) gee_iterator_get (d_it));
+				{
+					vala_namespace_add_delegate (old_ns, d);
+					(d == NULL ? NULL : (d = (g_object_unref (d), NULL)));
+				}
+			}
+			(d_collection == NULL ? NULL : (d_collection = (g_object_unref (d_collection), NULL)));
+			(d_it == NULL ? NULL : (d_it = (g_object_unref (d_it), NULL)));
+		}
+		{
+			GeeCollection* en_collection;
+			GeeIterator* en_it;
+			en_collection = vala_namespace_get_enums (ns);
+			en_it = gee_iterable_iterator (GEE_ITERABLE (en_collection));
+			while (gee_iterator_next (en_it)) {
+				ValaEnum* en;
+				en = ((ValaEnum*) gee_iterator_get (en_it));
+				{
+					vala_namespace_add_enum (old_ns, en);
+					(en == NULL ? NULL : (en = (g_object_unref (en), NULL)));
+				}
+			}
+			(en_collection == NULL ? NULL : (en_collection = (g_object_unref (en_collection), NULL)));
+			(en_it == NULL ? NULL : (en_it = (g_object_unref (en_it), NULL)));
+		}
+		{
+			GeeCollection* ed_collection;
+			GeeIterator* ed_it;
+			ed_collection = vala_namespace_get_error_domains (ns);
+			ed_it = gee_iterable_iterator (GEE_ITERABLE (ed_collection));
+			while (gee_iterator_next (ed_it)) {
+				ValaErrorDomain* ed;
+				ed = ((ValaErrorDomain*) gee_iterator_get (ed_it));
+				{
+					vala_namespace_add_error_domain (old_ns, ed);
+					(ed == NULL ? NULL : (ed = (g_object_unref (ed), NULL)));
+				}
+			}
+			(ed_collection == NULL ? NULL : (ed_collection = (g_object_unref (ed_collection), NULL)));
+			(ed_it == NULL ? NULL : (ed_it = (g_object_unref (ed_it), NULL)));
+		}
+		{
+			GeeCollection* c_collection;
+			GeeIterator* c_it;
+			c_collection = vala_namespace_get_constants (ns);
+			c_it = gee_iterable_iterator (GEE_ITERABLE (c_collection));
+			while (gee_iterator_next (c_it)) {
+				ValaConstant* c;
+				c = ((ValaConstant*) gee_iterator_get (c_it));
+				{
+					vala_namespace_add_constant (old_ns, c);
+					(c == NULL ? NULL : (c = (g_object_unref (c), NULL)));
+				}
+			}
+			(c_collection == NULL ? NULL : (c_collection = (g_object_unref (c_collection), NULL)));
+			(c_it == NULL ? NULL : (c_it = (g_object_unref (c_it), NULL)));
+		}
+		{
+			GeeCollection* f_collection;
+			GeeIterator* f_it;
+			f_collection = vala_namespace_get_fields (ns);
+			f_it = gee_iterable_iterator (GEE_ITERABLE (f_collection));
+			while (gee_iterator_next (f_it)) {
+				ValaField* f;
+				f = ((ValaField*) gee_iterator_get (f_it));
+				{
+					vala_namespace_add_field (old_ns, f);
+					(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
+				}
+			}
+			(f_collection == NULL ? NULL : (f_collection = (g_object_unref (f_collection), NULL)));
+			(f_it == NULL ? NULL : (f_it = (g_object_unref (f_it), NULL)));
+		}
+		{
+			GeeCollection* m_collection;
+			GeeIterator* m_it;
+			m_collection = vala_namespace_get_methods (ns);
+			m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
+			while (gee_iterator_next (m_it)) {
+				ValaMethod* m;
+				m = ((ValaMethod*) gee_iterator_get (m_it));
+				{
+					vala_namespace_add_method (old_ns, m);
+					(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+				}
+			}
+			(m_collection == NULL ? NULL : (m_collection = (g_object_unref (m_collection), NULL)));
+			(m_it == NULL ? NULL : (m_it = (g_object_unref (m_it), NULL)));
+		}
+		(old_ns == NULL ? NULL : (old_ns = (g_object_unref (old_ns), NULL)));
+	} else {
+		gee_collection_add (GEE_COLLECTION (self->priv->namespaces), ns);
+		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (ns)), VALA_SYMBOL (ns));
+	}
 }
 
 
@@ -124,8 +298,72 @@ GeeCollection* vala_namespace_get_namespaces (ValaNamespace* self) {
 void vala_namespace_add_class (ValaNamespace* self, ValaClass* cl) {
 	g_return_if_fail (VALA_IS_NAMESPACE (self));
 	g_return_if_fail (VALA_IS_CLASS (cl));
-	gee_collection_add (GEE_COLLECTION (self->priv->classes), cl);
-	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cl)), VALA_SYMBOL (cl));
+	if (VALA_IS_CLASS (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cl))))) {
+		ValaClass* old_class;
+		/* merge*/
+		old_class = VALA_CLASS (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cl))));
+		{
+			GeeCollection* base_type_collection;
+			GeeIterator* base_type_it;
+			base_type_collection = vala_class_get_base_types (cl);
+			base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
+			while (gee_iterator_next (base_type_it)) {
+				ValaDataType* base_type;
+				base_type = ((ValaDataType*) gee_iterator_get (base_type_it));
+				{
+					vala_class_add_base_type (old_class, base_type);
+					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
+				}
+			}
+			(base_type_collection == NULL ? NULL : (base_type_collection = (g_object_unref (base_type_collection), NULL)));
+			(base_type_it == NULL ? NULL : (base_type_it = (g_object_unref (base_type_it), NULL)));
+		}
+		{
+			GeeCollection* f_collection;
+			GeeIterator* f_it;
+			f_collection = vala_class_get_fields (cl);
+			f_it = gee_iterable_iterator (GEE_ITERABLE (f_collection));
+			while (gee_iterator_next (f_it)) {
+				ValaField* f;
+				f = ((ValaField*) gee_iterator_get (f_it));
+				{
+					vala_class_add_field (old_class, f);
+					(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
+				}
+			}
+			(f_collection == NULL ? NULL : (f_collection = (g_object_unref (f_collection), NULL)));
+			(f_it == NULL ? NULL : (f_it = (g_object_unref (f_it), NULL)));
+		}
+		{
+			GeeCollection* m_collection;
+			GeeIterator* m_it;
+			m_collection = vala_class_get_methods (cl);
+			m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
+			while (gee_iterator_next (m_it)) {
+				ValaMethod* m;
+				m = ((ValaMethod*) gee_iterator_get (m_it));
+				{
+					if (m == vala_class_get_default_construction_method (cl) && vala_class_get_default_construction_method (old_class) != NULL) {
+						/* ignore secondary default creation method*/
+						(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+						continue;
+					}
+					vala_class_add_method (old_class, m);
+					(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+				}
+			}
+			(m_collection == NULL ? NULL : (m_collection = (g_object_unref (m_collection), NULL)));
+			(m_it == NULL ? NULL : (m_it = (g_object_unref (m_it), NULL)));
+		}
+		if (vala_class_get_constructor (cl) != NULL) {
+			vala_class_set_constructor (old_class, vala_class_get_constructor (cl));
+		}
+		vala_source_file_remove_node (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (cl))), VALA_CODE_NODE (cl));
+		(old_class == NULL ? NULL : (old_class = (g_object_unref (old_class), NULL)));
+	} else {
+		gee_collection_add (GEE_COLLECTION (self->priv->classes), cl);
+		vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (cl)), VALA_SYMBOL (cl));
+	}
 }
 
 
@@ -332,7 +570,7 @@ void vala_namespace_add_method (ValaNamespace* self, ValaMethod* m) {
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
 		return;
 	}
-	if (vala_method_get_instance (m)) {
+	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (m)), "instance methods not allowed outside of data types");
 		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
 		return;
