@@ -31,6 +31,7 @@
 #include <vala/valasourcereference.h>
 #include <vala/valamethodtype.h>
 #include <vala/valamemberaccess.h>
+#include <vala/valamember.h>
 
 
 
@@ -39,6 +40,7 @@ struct _ValaNullCheckerPrivate {
 	ValaCodeContext* context;
 	ValaDataType* current_return_type;
 };
+
 #define VALA_NULL_CHECKER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_NULL_CHECKER, ValaNullCheckerPrivate))
 enum  {
 	VALA_NULL_CHECKER_DUMMY_PROPERTY
@@ -50,6 +52,7 @@ static void vala_null_checker_real_visit_class (ValaCodeVisitor* base, ValaClass
 static void vala_null_checker_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st);
 static void vala_null_checker_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface);
 static void vala_null_checker_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en);
+static void vala_null_checker_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* ed);
 static void vala_null_checker_real_visit_field (ValaCodeVisitor* base, ValaField* f);
 static void vala_null_checker_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
 static void vala_null_checker_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m);
@@ -186,6 +189,14 @@ static void vala_null_checker_real_visit_enum (ValaCodeVisitor* base, ValaEnum*
 }
 
 
+static void vala_null_checker_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* ed) {
+	ValaNullChecker * self;
+	self = VALA_NULL_CHECKER (base);
+	g_return_if_fail (VALA_IS_ERROR_DOMAIN (ed));
+	vala_code_node_accept_children (VALA_CODE_NODE (ed), VALA_CODE_VISITOR (self));
+}
+
+
 static void vala_null_checker_real_visit_field (ValaCodeVisitor* base, ValaField* f) {
 	ValaNullChecker * self;
 	self = VALA_NULL_CHECKER (base);
@@ -401,7 +412,7 @@ static void vala_null_checker_real_visit_invocation_expression (ValaCodeVisitor*
 	_tmp3 = NULL;
 	_tmp2 = NULL;
 	ma = (_tmp3 = (_tmp2 = vala_invocation_expression_get_call (expr), (VALA_IS_MEMBER_ACCESS (_tmp2) ? ((ValaMemberAccess*) _tmp2) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
-	if (mtype != NULL && vala_method_get_instance (vala_method_type_get_method_symbol (mtype)) && ma != NULL) {
+	if (mtype != NULL && vala_method_get_binding (vala_method_type_get_method_symbol (mtype)) == MEMBER_BINDING_INSTANCE && ma != NULL) {
 		if (vala_member_access_get_inner (ma) == NULL) {
 		} else {
 			/* implicit this call, always non-null*/
@@ -477,6 +488,7 @@ static void vala_null_checker_class_init (ValaNullCheckerClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_null_checker_real_visit_struct;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_null_checker_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_null_checker_real_visit_enum;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_error_domain = vala_null_checker_real_visit_error_domain;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_field = vala_null_checker_real_visit_field;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method = vala_null_checker_real_visit_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_creation_method = vala_null_checker_real_visit_creation_method;
