@@ -1,6 +1,6 @@
 /* valanullliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,14 +24,19 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 enum  {
 	VALA_NULL_LITERAL_DUMMY_PROPERTY
 };
 static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_null_literal_real_to_string (ValaCodeNode* base);
+static gboolean vala_null_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_null_literal_parent_class = NULL;
 
 
+
 /**
  * Creates a new null literal.
  *
@@ -62,10 +67,18 @@ static char* vala_null_literal_real_to_string (ValaCodeNode* base) {
 }
 
 
+static gboolean vala_null_literal_real_is_pure (ValaExpression* base) {
+	ValaNullLiteral * self;
+	self = VALA_NULL_LITERAL (base);
+	return TRUE;
+}
+
+
 static void vala_null_literal_class_init (ValaNullLiteralClass * klass) {
 	vala_null_literal_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_null_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_null_literal_real_to_string;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_null_literal_real_is_pure;
 }
 
 
