@@ -21,8 +21,6 @@
  */
 
 #include <vala/valanulltype.h>
-#include <stdlib.h>
-#include <string.h>
 #include <vala/valacodenode.h>
 #include <vala/valapointertype.h>
 #include <vala/valatypesymbol.h>
@@ -37,6 +35,7 @@ enum  {
 };
 static gboolean vala_null_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static ValaDataType* vala_null_type_real_copy (ValaDataType* base);
+static char* vala_null_type_real_get_cname (ValaDataType* base);
 static gpointer vala_null_type_parent_class = NULL;
 
 
@@ -79,10 +78,18 @@ static ValaDataType* vala_null_type_real_copy (ValaDataType* base) {
 }
 
 
+static char* vala_null_type_real_get_cname (ValaDataType* base) {
+	ValaNullType * self;
+	self = VALA_NULL_TYPE (base);
+	return g_strdup ("gpointer");
+}
+
+
 static void vala_null_type_class_init (ValaNullTypeClass * klass) {
 	vala_null_type_parent_class = g_type_class_peek_parent (klass);
 	VALA_DATA_TYPE_CLASS (klass)->compatible = vala_null_type_real_compatible;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_null_type_real_copy;
+	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_null_type_real_get_cname;
 }
 
 
