@@ -45,26 +45,31 @@ typedef struct _ValaObjectCreationExpressionPrivate ValaObjectCreationExpression
  * Represents an object creation expression in the source code.
  */
 struct _ValaObjectCreationExpression {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaObjectCreationExpressionPrivate * priv;
 };
+
 struct _ValaObjectCreationExpressionClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
+
 ValaObjectCreationExpression* vala_object_creation_expression_new (ValaMemberAccess* member_name, ValaSourceReference* source_reference);
 void vala_object_creation_expression_add_argument (ValaObjectCreationExpression* self, ValaExpression* arg);
 GeeCollection* vala_object_creation_expression_get_argument_list (ValaObjectCreationExpression* self);
 void vala_object_creation_expression_add_member_initializer (ValaObjectCreationExpression* self, ValaMemberInitializer* init);
 GeeCollection* vala_object_creation_expression_get_object_initializer (ValaObjectCreationExpression* self);
-ValaTypeReference* vala_object_creation_expression_get_type_reference (ValaObjectCreationExpression* self);
-void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpression* self, ValaTypeReference* value);
+ValaDataType* vala_object_creation_expression_get_type_reference (ValaObjectCreationExpression* self);
+void vala_object_creation_expression_set_type_reference (ValaObjectCreationExpression* self, ValaDataType* value);
 ValaMethod* vala_object_creation_expression_get_constructor (ValaObjectCreationExpression* self);
 void vala_object_creation_expression_set_constructor (ValaObjectCreationExpression* self, ValaMethod* value);
 ValaMemberAccess* vala_object_creation_expression_get_member_name (ValaObjectCreationExpression* self);
 void vala_object_creation_expression_set_member_name (ValaObjectCreationExpression* self, ValaMemberAccess* value);
+gboolean vala_object_creation_expression_get_struct_creation (ValaObjectCreationExpression* self);
+void vala_object_creation_expression_set_struct_creation (ValaObjectCreationExpression* self, gboolean value);
 GType vala_object_creation_expression_get_type (void);
 
+
 G_END_DECLS
 
 #endif
