@@ -31,13 +31,14 @@
 struct _ValaPointerTypePrivate {
 	ValaDataType* _base_type;
 };
+
 #define VALA_POINTER_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_POINTER_TYPE, ValaPointerTypePrivate))
 enum  {
 	VALA_POINTER_TYPE_DUMMY_PROPERTY,
 	VALA_POINTER_TYPE_BASE_TYPE
 };
 static char* vala_pointer_type_real_to_string (ValaCodeNode* base);
-static char* vala_pointer_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type);
+static char* vala_pointer_type_real_get_cname (ValaDataType* base);
 static ValaDataType* vala_pointer_type_real_copy (ValaDataType* base);
 static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static ValaSymbol* vala_pointer_type_real_get_pointer_member (ValaDataType* base, const char* member_name);
@@ -69,17 +70,17 @@ static char* vala_pointer_type_real_to_string (ValaCodeNode* base) {
 }
 
 
-static char* vala_pointer_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type) {
+static char* vala_pointer_type_real_get_cname (ValaDataType* base) {
 	ValaPointerType * self;
 	self = VALA_POINTER_TYPE (base);
 	if (vala_data_type_get_data_type (self->priv->_base_type) != NULL && vala_typesymbol_is_reference_type (vala_data_type_get_data_type (self->priv->_base_type))) {
-		return vala_data_type_get_cname (self->priv->_base_type, var_type, const_type);
+		return vala_data_type_get_cname (self->priv->_base_type);
 	} else {
 		char* _tmp1;
 		char* _tmp2;
 		_tmp1 = NULL;
 		_tmp2 = NULL;
-		return (_tmp2 = g_strconcat ((_tmp1 = vala_data_type_get_cname (self->priv->_base_type, var_type, const_type)), "*", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
+		return (_tmp2 = g_strconcat ((_tmp1 = vala_data_type_get_cname (self->priv->_base_type)), "*", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
 	}
 }
 
