@@ -45,15 +45,16 @@ struct _ValaPropertyPrivate {
 	gboolean _is_virtual;
 	gboolean _overrides;
 	ValaField* _field;
+	MemberBinding _binding;
 	ValaProperty* _base_property;
 	ValaProperty* _base_interface_property;
 	ValaExpression* _default_expression;
 	gboolean lock_used;
 	ValaDataType* _data_type;
-	gboolean _instance;
 	char* _nick;
 	char* _blurb;
 };
+
 #define VALA_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY, ValaPropertyPrivate))
 enum  {
 	VALA_PROPERTY_DUMMY_PROPERTY,
@@ -68,7 +69,7 @@ enum  {
 	VALA_PROPERTY_IS_VIRTUAL,
 	VALA_PROPERTY_OVERRIDES,
 	VALA_PROPERTY_FIELD,
-	VALA_PROPERTY_INSTANCE,
+	VALA_PROPERTY_BINDING,
 	VALA_PROPERTY_BASE_PROPERTY,
 	VALA_PROPERTY_BASE_INTERFACE_PROPERTY,
 	VALA_PROPERTY_DEFAULT_EXPRESSION,
@@ -463,15 +464,15 @@ void vala_property_set_field (ValaProperty* self, ValaField* value) {
 }
 
 
-gboolean vala_property_get_instance (ValaProperty* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY (self), FALSE);
-	return self->priv->_instance;
+MemberBinding vala_property_get_binding (ValaProperty* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), 0);
+	return self->priv->_binding;
 }
 
 
-void vala_property_set_instance (ValaProperty* self, gboolean value) {
+void vala_property_set_binding (ValaProperty* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	self->priv->_instance = value;
+	self->priv->_binding = value;
 }
 
 
@@ -598,8 +599,8 @@ static void vala_property_get_property (GObject * object, guint property_id, GVa
 		case VALA_PROPERTY_FIELD:
 		g_value_set_object (value, vala_property_get_field (self));
 		break;
-		case VALA_PROPERTY_INSTANCE:
-		g_value_set_boolean (value, vala_property_get_instance (self));
+		case VALA_PROPERTY_BINDING:
+		g_value_set_enum (value, vala_property_get_binding (self));
 		break;
 		case VALA_PROPERTY_BASE_PROPERTY:
 		g_value_set_object (value, vala_property_get_base_property (self));
@@ -660,8 +661,8 @@ static void vala_property_set_property (GObject * object, guint property_id, con
 		case VALA_PROPERTY_FIELD:
 		vala_property_set_field (self, g_value_get_object (value));
 		break;
-		case VALA_PROPERTY_INSTANCE:
-		vala_property_set_instance (self, g_value_get_boolean (value));
+		case VALA_PROPERTY_BINDING:
+		vala_property_set_binding (self, g_value_get_enum (value));
 		break;
 		case VALA_PROPERTY_BASE_PROPERTY:
 		vala_property_set_base_property (self, g_value_get_object (value));
@@ -705,7 +706,7 @@ static void vala_property_class_init (ValaPropertyClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "is-virtual", "is-virtual", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_OVERRIDES, g_param_spec_boolean ("overrides", "overrides", "overrides", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_FIELD, g_param_spec_object ("field", "field", "field", VALA_TYPE_FIELD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_PROPERTY, g_param_spec_object ("base-property", "base-property", "base-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_INTERFACE_PROPERTY, g_param_spec_object ("base-interface-property", "base-interface-property", "base-interface-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -723,8 +724,8 @@ static void vala_property_vala_lockable_interface_init (ValaLockableIface * ifac
 
 static void vala_property_init (ValaProperty * self) {
 	self->priv = VALA_PROPERTY_GET_PRIVATE (self);
+	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 	self->priv->lock_used = FALSE;
-	self->priv->_instance = TRUE;
 }
 
 
