@@ -51,10 +51,12 @@ struct _ValaProperty {
 	ValaMember parent_instance;
 	ValaPropertyPrivate * priv;
 };
+
 struct _ValaPropertyClass {
 	ValaMemberClass parent_class;
 };
 
+
 ValaProperty* vala_property_new (const char* _name, ValaDataType* type, ValaPropertyAccessor* _get_accessor, ValaPropertyAccessor* _set_accessor, ValaSourceReference* source);
 char* vala_property_get_upper_case_cname (ValaProperty* self);
 ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self);
@@ -82,8 +84,8 @@ gboolean vala_property_get_overrides (ValaProperty* self);
 void vala_property_set_overrides (ValaProperty* self, gboolean value);
 ValaField* vala_property_get_field (ValaProperty* self);
 void vala_property_set_field (ValaProperty* self, ValaField* value);
-gboolean vala_property_get_instance (ValaProperty* self);
-void vala_property_set_instance (ValaProperty* self, gboolean value);
+MemberBinding vala_property_get_binding (ValaProperty* self);
+void vala_property_set_binding (ValaProperty* self, MemberBinding value);
 ValaProperty* vala_property_get_base_property (ValaProperty* self);
 void vala_property_set_base_property (ValaProperty* self, ValaProperty* value);
 ValaProperty* vala_property_get_base_interface_property (ValaProperty* self);
