@@ -32,6 +32,16 @@ static gpointer vala_reference_type_parent_class = NULL;
 
 
 
+/**
+ * A reference type, i.e. a class, interface, or array type.
+ */
+ValaReferenceType* vala_reference_type_new (void) {
+	ValaReferenceType * self;
+	self = g_object_newv (VALA_TYPE_REFERENCE_TYPE, 0, NULL);
+	return self;
+}
+
+
 static void vala_reference_type_class_init (ValaReferenceTypeClass * klass) {
 	vala_reference_type_parent_class = g_type_class_peek_parent (klass);
 }
