@@ -36,6 +36,7 @@ struct _ValaScannerPrivate {
 	gint column;
 	char* _comment;
 };
+
 #define VALA_SCANNER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SCANNER, ValaScannerPrivate))
 enum  {
 	VALA_SCANNER_DUMMY_PROPERTY,
@@ -935,7 +936,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 									break;
 								} else {
 									gunichar u;
-									u = g_utf8_get_char_validated ((((char*) self->priv->current)), ((glong) (self->priv->end - self->priv->current)));
+									u = g_utf8_get_char_validated ((((const char*) self->priv->current)), ((glong) (self->priv->end - self->priv->current)));
 									if (u != ((gunichar) (-1))) {
 										self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
 										token_length_in_chars++;
@@ -963,7 +964,7 @@ ValaTokenType vala_scanner_read_token (ValaScanner* self, ValaSourceLocation* to
 					} while (0); else
 					do {
 						gunichar u;
-						u = g_utf8_get_char_validated ((((char*) self->priv->current)), ((glong) (self->priv->end - self->priv->current)));
+						u = g_utf8_get_char_validated ((((const char*) self->priv->current)), ((glong) (self->priv->end - self->priv->current)));
 						if (u != ((gunichar) (-1))) {
 							ValaSourceReference* _tmp9;
 							self->priv->current = self->priv->current + (g_unichar_to_utf8 (u, NULL));
@@ -1048,7 +1049,7 @@ static gboolean vala_scanner_comment (ValaScanner* self) {
 			self->priv->current++;
 		}
 		_tmp1 = NULL;
-		vala_scanner_push_comment (self, (_tmp1 = g_strndup ((((char*) begin)), ((gulong) ((glong) (self->priv->current - begin))))), self->priv->line == 1);
+		vala_scanner_push_comment (self, (_tmp1 = g_strndup ((((const char*) begin)), ((gulong) ((glong) (self->priv->current - begin))))), self->priv->line == 1);
 		_tmp1 = (g_free (_tmp1), NULL);
 	} else {
 		gchar* begin;
@@ -1074,7 +1075,7 @@ static gboolean vala_scanner_comment (ValaScanner* self) {
 			return TRUE;
 		}
 		_tmp4 = NULL;
-		vala_scanner_push_comment (self, (_tmp4 = g_strndup ((((char*) begin)), ((gulong) ((glong) (self->priv->current - begin))))), begin_line == 1);
+		vala_scanner_push_comment (self, (_tmp4 = g_strndup ((((const char*) begin)), ((gulong) ((glong) (self->priv->current - begin))))), begin_line == 1);
 		_tmp4 = (g_free (_tmp4), NULL);
 		self->priv->current = self->priv->current + (2);
 		self->priv->column = self->priv->column + (2);
