@@ -35,6 +35,7 @@ struct _ValaScopePrivate {
 	ValaScope* _parent_scope;
 	GeeMap* symbol_table;
 };
+
 #define VALA_SCOPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SCOPE, ValaScopePrivate))
 enum  {
 	VALA_SCOPE_DUMMY_PROPERTY,
@@ -91,7 +92,7 @@ void vala_scope_add (ValaScope* self, const char* name, ValaSymbol* sym) {
 				return;
 			}
 		}
-		gee_map_set (((GeeMap*) self->priv->symbol_table), ((char*) name), sym);
+		gee_map_set (((GeeMap*) self->priv->symbol_table), ((const char*) name), sym);
 	}
 	vala_symbol_set_owner (sym, self);
 }
