@@ -29,7 +29,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valabindingprovider.h>
 #include <vala/valacodecontext.h>
 #include <vala/valasourcefile.h>
 #include <vala/valaclass.h>
@@ -37,6 +36,7 @@
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
+#include <vala/valaerrordomain.h>
 #include <vala/valadelegate.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
@@ -50,7 +50,7 @@
 #include <vala/valadestructor.h>
 #include <vala/valanamedargument.h>
 #include <vala/valablock.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valainitializerlist.h>
 #include <vala/valaexpressionstatement.h>
 #include <vala/valaifstatement.h>
@@ -72,7 +72,6 @@
 #include <vala/valarealliteral.h>
 #include <vala/valastringliteral.h>
 #include <vala/valanullliteral.h>
-#include <vala/valaliteralexpression.h>
 #include <vala/valasymbol.h>
 #include <vala/valaparenthesizedexpression.h>
 #include <vala/valamemberaccess.h>
@@ -117,17 +116,19 @@ struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 };
+
 struct _ValaSemanticAnalyzerClass {
 	ValaCodeVisitorClass parent_class;
 };
 
+
 ValaSemanticAnalyzer* vala_semantic_analyzer_new (void);
-void vala_semantic_analyzer_add_binding_provider (ValaSemanticAnalyzer* self, ValaBindingProvider* binding_provider);
 void vala_semantic_analyzer_analyze (ValaSemanticAnalyzer* self, ValaCodeContext* context);
 ValaSymbol* vala_semantic_analyzer_symbol_lookup_inherited (ValaSymbol* sym, const char* name);
 ValaDataType* vala_semantic_analyzer_get_actual_type (ValaDataType* derived_instance_type, ValaSymbol* generic_member, ValaDataType* generic_type, ValaCodeNode* node_reference);
 GType vala_semantic_analyzer_get_type (void);
 
+
 G_END_DECLS
 
 #endif
