@@ -32,8 +32,8 @@
 #include <vala/valascope.h>
 #include <vala/valareferencetype.h>
 #include <vala/valaclass.h>
-#include <vala/valaclasstype.h>
-#include <vala/valainterfacetype.h>
+#include <vala/valaclassinstancetype.h>
+#include <vala/valainterfaceinstancetype.h>
 #include <vala/valainterface.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
@@ -49,6 +49,7 @@ struct _ValaSignalPrivate {
 	gboolean lock_used;
 	ValaDataType* _return_type;
 };
+
 #define VALA_SIGNAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIGNAL, ValaSignalPrivate))
 enum  {
 	VALA_SIGNAL_DUMMY_PROPERTY,
@@ -126,16 +127,16 @@ ValaDelegate* vala_signal_get_delegate (ValaSignal* self) {
 		ValaFormalParameter* sender_param;
 		_tmp0 = NULL;
 		self->priv->generated_delegate = (_tmp0 = vala_delegate_new (NULL, vala_signal_get_return_type (self), NULL), (self->priv->generated_delegate == NULL ? NULL : (self->priv->generated_delegate = (g_object_unref (self->priv->generated_delegate), NULL))), _tmp0);
-		vala_delegate_set_instance (self->priv->generated_delegate, TRUE);
+		vala_delegate_set_has_target (self->priv->generated_delegate, TRUE);
 		sender_type = NULL;
 		if (VALA_IS_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))) {
 			ValaReferenceType* _tmp1;
 			_tmp1 = NULL;
-			sender_type = (_tmp1 = VALA_REFERENCE_TYPE (vala_class_type_new (VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp1);
+			sender_type = (_tmp1 = VALA_REFERENCE_TYPE (vala_class_instance_type_new (VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp1);
 		} else {
 			ValaReferenceType* _tmp2;
 			_tmp2 = NULL;
-			sender_type = (_tmp2 = VALA_REFERENCE_TYPE (vala_interface_type_new (VALA_INTERFACE (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp2);
+			sender_type = (_tmp2 = VALA_REFERENCE_TYPE (vala_interface_instance_type_new (VALA_INTERFACE (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp2);
 		}
 		sender_param = vala_formal_parameter_new ("sender", VALA_DATA_TYPE (sender_type), NULL);
 		vala_delegate_add_parameter (self->priv->generated_delegate, sender_param);
