@@ -32,12 +32,13 @@
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
+#include <vala/valamember.h>
+#include <vala/valacreationmethod.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valavaluetype.h>
 #include <vala/valavoidtype.h>
 #include <vala/valalocalvariable.h>
 #include <vala/valaexpression.h>
-#include <vala/valacreationmethod.h>
 #include <vala/valareport.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
@@ -69,6 +70,7 @@ struct _ValaStructPrivate {
 	char* type_signature;
 	ValaMethod* _default_construction_method;
 };
+
 #define VALA_STRUCT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRUCT, ValaStructPrivate))
 enum  {
 	VALA_STRUCT_DUMMY_PROPERTY,
@@ -137,6 +139,17 @@ void vala_struct_add_type_parameter (ValaStruct* self, ValaTypeParameter* p) {
 }
 
 
+/**
+ * Returns a copy of the type parameter list.
+ *
+ * @return list of type parameters
+ */
+GeeCollection* vala_struct_get_type_parameters (ValaStruct* self) {
+	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->type_parameters)));
+}
+
+
 /**
  * Adds the specified constant as a member to this struct.
  *
@@ -185,7 +198,7 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m) {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_METHOD (m));
 	g_return_if_fail (m != NULL);
-	if (vala_method_get_instance (m)) {
+	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE || VALA_IS_CREATION_METHOD (m)) {
 		ValaFormalParameter* _tmp1;
 		ValaValueType* _tmp0;
 		_tmp1 = NULL;
@@ -343,7 +356,7 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 
 static char* vala_struct_real_get_cname (ValaTypesymbol* base, gboolean const_type) {
 	ValaStruct * self;
-	const char* _tmp4;
+	const char* _tmp3;
 	self = VALA_STRUCT (base);
 	if (const_type && self->priv->const_cname != NULL) {
 		const char* _tmp0;
@@ -351,15 +364,27 @@ static char* vala_struct_real_get_cname (ValaTypesymbol* base, gboolean const_ty
 		return (_tmp0 = self->priv->const_cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	}
 	if (self->priv->cname == NULL) {
-		char* _tmp3;
 		char* _tmp2;
-		_tmp3 = NULL;
 		_tmp2 = NULL;
-		self->priv->cname = (_tmp3 = g_strdup_printf ("%s%s", (_tmp2 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp3);
-		_tmp2 = (g_free (_tmp2), NULL);
+		self->priv->cname = (_tmp2 = vala_struct_get_default_cname (self), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp2);
 	}
-	_tmp4 = NULL;
-	return (_tmp4 = self->priv->cname, (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
+	_tmp3 = NULL;
+	return (_tmp3 = self->priv->cname, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+}
+
+
+/**
+ * Returns the default name of this struct as it is used in C code.
+ *
+ * @return the name to be used in C code by default
+ */
+char* vala_struct_get_default_cname (ValaStruct* self) {
+	char* _tmp0;
+	char* _tmp1;
+	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%s%s", (_tmp0 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -458,6 +483,31 @@ static char* vala_struct_real_get_type_signature (ValaTypesymbol* base) {
  */
 gboolean vala_struct_is_integer_type (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), FALSE);
+	{
+		GeeList* type_collection;
+		GeeIterator* type_it;
+		type_collection = self->priv->base_types;
+		type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+		while (gee_iterator_next (type_it)) {
+			ValaDataType* type;
+			type = ((ValaDataType*) gee_iterator_get (type_it));
+			{
+				ValaStruct* _tmp1;
+				ValaTypesymbol* _tmp0;
+				ValaStruct* st;
+				_tmp1 = NULL;
+				_tmp0 = NULL;
+				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				if (st != NULL && vala_struct_is_integer_type (st)) {
+					gboolean _tmp2;
+					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), (type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL))), _tmp2);
+				}
+				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+			}
+		}
+		(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+	}
 	return self->priv->integer_type;
 }
 
@@ -469,6 +519,31 @@ gboolean vala_struct_is_integer_type (ValaStruct* self) {
  */
 gboolean vala_struct_is_floating_type (ValaStruct* self) {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), FALSE);
+	{
+		GeeList* type_collection;
+		GeeIterator* type_it;
+		type_collection = self->priv->base_types;
+		type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+		while (gee_iterator_next (type_it)) {
+			ValaDataType* type;
+			type = ((ValaDataType*) gee_iterator_get (type_it));
+			{
+				ValaStruct* _tmp1;
+				ValaTypesymbol* _tmp0;
+				ValaStruct* st;
+				_tmp1 = NULL;
+				_tmp0 = NULL;
+				st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				if (st != NULL && vala_struct_is_floating_type (st)) {
+					gboolean _tmp2;
+					return (_tmp2 = TRUE, (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), (type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL))), _tmp2);
+				}
+				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+			}
+		}
+		(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+	}
 	return self->priv->floating_type;
 }
 
@@ -624,23 +699,49 @@ void vala_struct_process_attributes (ValaStruct* self) {
 
 static char* vala_struct_real_get_type_id (ValaTypesymbol* base) {
 	ValaStruct * self;
-	const char* _tmp3;
+	const char* _tmp6;
 	self = VALA_STRUCT (base);
 	if (self->priv->type_id == NULL) {
+		{
+			GeeList* type_collection;
+			GeeIterator* type_it;
+			type_collection = self->priv->base_types;
+			type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+			while (gee_iterator_next (type_it)) {
+				ValaDataType* type;
+				type = ((ValaDataType*) gee_iterator_get (type_it));
+				{
+					ValaStruct* _tmp1;
+					ValaTypesymbol* _tmp0;
+					ValaStruct* st;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					if (st != NULL) {
+						char* _tmp2;
+						_tmp2 = NULL;
+						return (_tmp2 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), (type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL))), _tmp2);
+					}
+					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				}
+			}
+			(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+		}
 		if (self->priv->simple_type) {
-			char* _tmp1;
-			char* _tmp0;
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp1 = g_strdup_printf ("The type `%s` doesn't declare a type id", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
-			_tmp1 = (g_free (_tmp1), NULL);
-			_tmp0 = (g_free (_tmp0), NULL);
+			char* _tmp4;
+			char* _tmp3;
+			_tmp4 = NULL;
+			_tmp3 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp4 = g_strdup_printf ("The type `%s` doesn't declare a type id", (_tmp3 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+			_tmp4 = (g_free (_tmp4), NULL);
+			_tmp3 = (g_free (_tmp3), NULL);
 		} else {
 			return g_strdup ("G_TYPE_POINTER");
 		}
 	}
-	_tmp3 = NULL;
-	return (_tmp3 = self->priv->type_id, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+	_tmp6 = NULL;
+	return (_tmp6 = self->priv->type_id, (_tmp6 == NULL ? NULL : g_strdup (_tmp6)));
 }
 
 
@@ -656,23 +757,49 @@ void vala_struct_set_type_id (ValaStruct* self, const char* name) {
 
 static char* vala_struct_real_get_marshaller_type_name (ValaTypesymbol* base) {
 	ValaStruct * self;
-	const char* _tmp3;
+	const char* _tmp6;
 	self = VALA_STRUCT (base);
 	if (self->priv->marshaller_type_name == NULL) {
+		{
+			GeeList* type_collection;
+			GeeIterator* type_it;
+			type_collection = self->priv->base_types;
+			type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+			while (gee_iterator_next (type_it)) {
+				ValaDataType* type;
+				type = ((ValaDataType*) gee_iterator_get (type_it));
+				{
+					ValaStruct* _tmp1;
+					ValaTypesymbol* _tmp0;
+					ValaStruct* st;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					if (st != NULL) {
+						char* _tmp2;
+						_tmp2 = NULL;
+						return (_tmp2 = vala_typesymbol_get_marshaller_type_name (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), (type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL))), _tmp2);
+					}
+					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				}
+			}
+			(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+		}
 		if (self->priv->simple_type) {
-			char* _tmp1;
-			char* _tmp0;
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp1 = g_strdup_printf ("The type `%s` doesn't declare a marshaller type name", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
-			_tmp1 = (g_free (_tmp1), NULL);
-			_tmp0 = (g_free (_tmp0), NULL);
+			char* _tmp4;
+			char* _tmp3;
+			_tmp4 = NULL;
+			_tmp3 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp4 = g_strdup_printf ("The type `%s` doesn't declare a marshaller type name", (_tmp3 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+			_tmp4 = (g_free (_tmp4), NULL);
+			_tmp3 = (g_free (_tmp3), NULL);
 		} else {
 			return g_strdup ("POINTER");
 		}
 	}
-	_tmp3 = NULL;
-	return (_tmp3 = self->priv->marshaller_type_name, (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+	_tmp6 = NULL;
+	return (_tmp6 = self->priv->marshaller_type_name, (_tmp6 == NULL ? NULL : g_strdup (_tmp6)));
 }
 
 
@@ -690,22 +817,48 @@ static char* vala_struct_real_get_get_value_function (ValaTypesymbol* base) {
 	ValaStruct * self;
 	self = VALA_STRUCT (base);
 	if (self->priv->get_value_function == NULL) {
+		{
+			GeeList* type_collection;
+			GeeIterator* type_it;
+			type_collection = self->priv->base_types;
+			type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+			while (gee_iterator_next (type_it)) {
+				ValaDataType* type;
+				type = ((ValaDataType*) gee_iterator_get (type_it));
+				{
+					ValaStruct* _tmp1;
+					ValaTypesymbol* _tmp0;
+					ValaStruct* st;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					if (st != NULL) {
+						char* _tmp2;
+						_tmp2 = NULL;
+						return (_tmp2 = vala_typesymbol_get_get_value_function (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), (type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL))), _tmp2);
+					}
+					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				}
+			}
+			(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+		}
 		if (self->priv->simple_type) {
-			char* _tmp1;
-			char* _tmp0;
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp1 = g_strdup_printf ("The value type `%s` doesn't declare a GValue get function", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
-			_tmp1 = (g_free (_tmp1), NULL);
-			_tmp0 = (g_free (_tmp0), NULL);
+			char* _tmp4;
+			char* _tmp3;
+			_tmp4 = NULL;
+			_tmp3 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp4 = g_strdup_printf ("The value type `%s` doesn't declare a GValue get function", (_tmp3 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+			_tmp4 = (g_free (_tmp4), NULL);
+			_tmp3 = (g_free (_tmp3), NULL);
 			return NULL;
 		} else {
 			return g_strdup ("g_value_get_pointer");
 		}
 	} else {
-		const char* _tmp4;
-		_tmp4 = NULL;
-		return (_tmp4 = self->priv->get_value_function, (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
+		const char* _tmp7;
+		_tmp7 = NULL;
+		return (_tmp7 = self->priv->get_value_function, (_tmp7 == NULL ? NULL : g_strdup (_tmp7)));
 	}
 }
 
@@ -714,22 +867,48 @@ static char* vala_struct_real_get_set_value_function (ValaTypesymbol* base) {
 	ValaStruct * self;
 	self = VALA_STRUCT (base);
 	if (self->priv->set_value_function == NULL) {
+		{
+			GeeList* type_collection;
+			GeeIterator* type_it;
+			type_collection = self->priv->base_types;
+			type_it = gee_iterable_iterator (GEE_ITERABLE (type_collection));
+			while (gee_iterator_next (type_it)) {
+				ValaDataType* type;
+				type = ((ValaDataType*) gee_iterator_get (type_it));
+				{
+					ValaStruct* _tmp1;
+					ValaTypesymbol* _tmp0;
+					ValaStruct* st;
+					_tmp1 = NULL;
+					_tmp0 = NULL;
+					st = (_tmp1 = (_tmp0 = vala_data_type_get_data_type (type), (VALA_IS_STRUCT (_tmp0) ? ((ValaStruct*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					if (st != NULL) {
+						char* _tmp2;
+						_tmp2 = NULL;
+						return (_tmp2 = vala_typesymbol_get_set_value_function (VALA_TYPESYMBOL (st)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (st == NULL ? NULL : (st = (g_object_unref (st), NULL))), (type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL))), _tmp2);
+					}
+					(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+					(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
+				}
+			}
+			(type_it == NULL ? NULL : (type_it = (g_object_unref (type_it), NULL)));
+		}
 		if (self->priv->simple_type) {
-			char* _tmp1;
-			char* _tmp0;
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp1 = g_strdup_printf ("The value type `%s` doesn't declare a GValue set function", (_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
-			_tmp1 = (g_free (_tmp1), NULL);
-			_tmp0 = (g_free (_tmp0), NULL);
+			char* _tmp4;
+			char* _tmp3;
+			_tmp4 = NULL;
+			_tmp3 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp4 = g_strdup_printf ("The value type `%s` doesn't declare a GValue set function", (_tmp3 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+			_tmp4 = (g_free (_tmp4), NULL);
+			_tmp3 = (g_free (_tmp3), NULL);
 			return NULL;
 		} else {
 			return g_strdup ("g_value_set_pointer");
 		}
 	} else {
-		const char* _tmp4;
-		_tmp4 = NULL;
-		return (_tmp4 = self->priv->set_value_function, (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
+		const char* _tmp7;
+		_tmp7 = NULL;
+		return (_tmp7 = self->priv->set_value_function, (_tmp7 == NULL ? NULL : g_strdup (_tmp7)));
 	}
 }
 
