@@ -39,9 +39,8 @@
 #include <vala/valatypeparametertype.h>
 #include <vala/valadelegatetype.h>
 #include <vala/valaerrortype.h>
-#include <vala/valaerrordomain.h>
-#include <vala/valaclasstype.h>
-#include <vala/valainterfacetype.h>
+#include <vala/valaclassinstancetype.h>
+#include <vala/valainterfaceinstancetype.h>
 #include <vala/valavaluetype.h>
 #include <vala/valapointertype.h>
 #include <vala/valaarraytype.h>
@@ -55,6 +54,7 @@ struct _ValaSymbolResolverPrivate {
 	ValaScope* current_scope;
 	GeeCollection* current_using_directives;
 };
+
 #define VALA_SYMBOL_RESOLVER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SYMBOL_RESOLVER, ValaSymbolResolverPrivate))
 enum  {
 	VALA_SYMBOL_RESOLVER_DUMMY_PROPERTY
@@ -64,6 +64,7 @@ static void vala_symbol_resolver_real_visit_class (ValaCodeVisitor* base, ValaCl
 static void vala_symbol_resolver_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st);
 static void vala_symbol_resolver_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface);
 static void vala_symbol_resolver_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en);
+static void vala_symbol_resolver_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* ed);
 static void vala_symbol_resolver_real_visit_delegate (ValaCodeVisitor* base, ValaDelegate* cb);
 static void vala_symbol_resolver_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c);
 static void vala_symbol_resolver_real_visit_field (ValaCodeVisitor* base, ValaField* f);
@@ -304,6 +305,24 @@ static void vala_symbol_resolver_real_visit_enum (ValaCodeVisitor* base, ValaEnu
 }
 
 
+static void vala_symbol_resolver_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* ed) {
+	ValaSymbolResolver * self;
+	ValaScope* _tmp1;
+	ValaScope* _tmp0;
+	ValaScope* _tmp3;
+	ValaScope* _tmp2;
+	self = VALA_SYMBOL_RESOLVER (base);
+	g_return_if_fail (VALA_IS_ERROR_DOMAIN (ed));
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	self->priv->current_scope = (_tmp1 = (_tmp0 = vala_symbol_get_scope (VALA_SYMBOL (ed)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp1);
+	vala_code_node_accept_children (VALA_CODE_NODE (ed), VALA_CODE_VISITOR (self));
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	self->priv->current_scope = (_tmp3 = (_tmp2 = vala_scope_get_parent_scope (self->priv->current_scope), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (self->priv->current_scope == NULL ? NULL : (self->priv->current_scope = (g_object_unref (self->priv->current_scope), NULL))), _tmp3);
+}
+
+
 static void vala_symbol_resolver_real_visit_delegate (ValaCodeVisitor* base, ValaDelegate* cb) {
 	ValaSymbolResolver * self;
 	ValaScope* _tmp1;
@@ -593,14 +612,14 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 					} else {
 						ValaDataType* _tmp8;
 						_tmp8 = NULL;
-						type = (_tmp8 = VALA_DATA_TYPE (vala_class_type_new (cl)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp8);
+						type = (_tmp8 = VALA_DATA_TYPE (vala_class_instance_type_new (cl)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp8);
 					}
 					(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
 				} else {
 					if (VALA_IS_INTERFACE (sym)) {
 						ValaDataType* _tmp9;
 						_tmp9 = NULL;
-						type = (_tmp9 = VALA_DATA_TYPE (vala_interface_type_new (VALA_INTERFACE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp9);
+						type = (_tmp9 = VALA_DATA_TYPE (vala_interface_instance_type_new (VALA_INTERFACE (sym))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp9);
 					} else {
 						if (VALA_IS_STRUCT (sym)) {
 							ValaDataType* _tmp10;
@@ -700,6 +719,8 @@ static ValaDataType* vala_symbol_resolver_resolve_type (ValaSymbolResolver* self
 		ValaDataType* _tmp22;
 		_tmp21 = NULL;
 		element_type = (_tmp21 = type, (_tmp21 == NULL ? NULL : g_object_ref (_tmp21)));
+		/* array contains strong references by default*/
+		vala_data_type_set_takes_ownership (element_type, vala_data_type_is_reference_type_or_type_parameter (element_type));
 		vala_data_type_set_transfers_ownership (element_type, FALSE);
 		vala_data_type_set_nullable (element_type, FALSE);
 		_tmp22 = NULL;
@@ -900,6 +921,7 @@ static void vala_symbol_resolver_class_init (ValaSymbolResolverClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_symbol_resolver_real_visit_struct;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_symbol_resolver_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_symbol_resolver_real_visit_enum;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_error_domain = vala_symbol_resolver_real_visit_error_domain;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_delegate = vala_symbol_resolver_real_visit_delegate;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_constant = vala_symbol_resolver_real_visit_constant;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_field = vala_symbol_resolver_real_visit_field;
