@@ -30,7 +30,7 @@ enum  {
 };
 static gboolean vala_void_type_real_stricter (ValaDataType* base, ValaDataType* type2);
 static char* vala_void_type_real_to_string (ValaCodeNode* base);
-static char* vala_void_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type);
+static char* vala_void_type_real_get_cname (ValaDataType* base);
 static ValaDataType* vala_void_type_real_copy (ValaDataType* base);
 static gpointer vala_void_type_parent_class = NULL;
 
@@ -58,7 +58,7 @@ static char* vala_void_type_real_to_string (ValaCodeNode* base) {
 }
 
 
-static char* vala_void_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type) {
+static char* vala_void_type_real_get_cname (ValaDataType* base) {
 	ValaVoidType * self;
 	self = VALA_VOID_TYPE (base);
 	return g_strdup ("void");
